% Function for processing closed chamber data
% and chamber fluxes
% and discarding a variable number of seconds at beginning & end
...

function [] = chamberflux_example(headerfilename, rawdatafilename, metdatafilename, resultsfilename, startrowheader, control, discardstart, interval, mode, before, after, gas, watercorrection)
% chamberflux_example('Example_Header.csv','Example_Rawdata.csv','Example_Metdata.csv','Example_Results.csv','1','m','40','100','0','30','30','CO_2','1')
%%% explanation of function arguments:
% - headerfilename: name of header file in .csv-format; example: 'headerfile_Kevo_lars.csv'
% - rawdatafilename: name of rawdata file in .csv-format; example: 'co2_Kevo_98_data_lars.csv'
% - metdatafilename: name of meteodata file in .csv-format; example: 'xxxx.csv.'
% - resultsfilename: name of results file in .csv-format; example: 'co2_Kevo_98_results.csv'
% - startrowheader: number of line in the header from which calculation will be started
% - control; options:  'm' (manual adjustment of discard intervals possible, manual "button-click" for next), 'f' (fixed discard intervals, automatic run)
% - discardstart: interval at experiment start which shall be discarded (in s); example: '10' (- discardend: interval at experiment end which shall be discarded (in s); example: '10')
% - interval: time interval (in s) for flux calculation; example: '100'
% - mode; options: '0': t=0 at headerdata(i,1)+discardstart; '1': t=0 at headerdata(i,1)
% - before: interval before experiment start (in s) where data points shall be plotted (not used for calculations); example: '50'
% - after: interval after experiment stop (in s) where data points shall be plotted (not used for calculations); example: '50'
% - gas: indicate gas of interest: 'ch4', 'co2' or 'h2o'
% - watercorrection; options: '0' water correction shall not be applied; '1' water correction shall be applied. 

% control 
if nargin < 13              % Check Input Parameter
   error('Not enough arguments. Syntax: chamberflux2014(headerfilename, rawdatafilename, metdatafilename, resultsfilename, startrowheader, control, discardstart, interval, mode, before, after, gas, watercorrection)');
end

% constants
R = 8.31447;                % ideal gas constant in JK-1mol-1
area_collar = 0.25;         % in m2

% selection of gas used for calculation
if gas == 'CO_2'
molmass_gas = 44.01;        % molar mass of co2 in g mol-1
noise_gas = 0.6;            % user-defined variable (2 times repeatability at 5 sec)
conc_unit_factor = 0.000001;%according to unit (e.g. %, ppm, etc.)
gascol = 11;
min_gas = 100;
max_gas = 5000;
elseif gas == 'CH_4'
molmass_gas = 16.04;        % molar mass of ch4 in g mol-1
noise_gas = 0.004;          % user-defined variable (2 times repeatability at 5 sec)
conc_unit_factor = 0.000001;%according to unit (e.g. %, ppm, etc.)
gascol = 9;
min_gas = 1;
max_gas = 100;
elseif gas == 'H_2O'
molmass_gas = 18.02;        % molar mass of h20 in g mol-1
noise_gas = 200;            % user-defined variable (repeatability at 5 sec)
conc_unit_factor = 0.000001;%according to unit (e.g. %, ppm, etc.)
gascol = 13;
min_gas = 100;
max_gas = 50000;
else
error('program not designed for this gas');
end

h2ocol = 13;
min_h2o = 100;
max_h2o = 50000;
conc_unit_factor_h2o = 0.000001;

startrowheader = str2num(startrowheader);


%%%%%%%IMPORTANT FOR USER !!!%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Configuration: Where to find which value?

% Headerdata
    idcol = 3;       % column number of location id
    lidacol = 4;     % column number of light/dark code
    thawcol = 7;     % column number of thaw depth
    sampcol = 5;     % column number of sample number 
    volcol = 6;      % column number of headspace volume
    Tsurfcol = 8;    % column number of surface temperature

    
% Rawdata
    timecol = 1;        % column number of time stamp
    parcol = 3;         % column number of PAR inside chamber
    tincol = 4;         % column number of temperatur inside chamber
    tsoilcol = 6;       % column number of temperatur in soil
    vwccol = 8;         % column number of volumetric water content in soil
    ch4col_moist = 9;   % column number of CH4 concentration (referred to moist air)
    ch4col_dry = 10;	% column number of CH4 concentration (referred to dry air)
    co2col_moist = 11;  % column number of CO2 concentration (referred to moist air)
    co2col_dry = 12;    % column number of CO2 concentration (referred to dry air)
    h2ocol = 13;        % column number of H2O concentration
 
        
% Metdata (selected variables from available metdata)
    timemetcol = 1;         % column number of time stamp
    mettempcol = 3;         % column number of air temperature at 2m height
    metrhcol = 4;           % column number of relative humidity at 2m height
    metLWoutcol = 5;        % column number of surface longwave radiation (for T calculation)
    metPARincol = 6;       % column number of PAR at meteorologic station
    metraincol = 7;        % column number of rainfall
    metpressurecol = 8;    % column number of air pressure
    metwindspeedcol = 9;   % column number of wind speed at 2m height
    metwinddirectcol = 10;  % column number of wind direction at 2m height
    metPARoutcol = 12;      % column number of PAR reflected


    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 

% quantities for error propagation for flux calculation
                
err_p=150/1000;       % uncertainty of pressure kPa
err_V=0.00721;        % uncertainty of height 0.02m, chamber height 0.3-0.32m
err_A=0.0012;         % uncertainty of length 0.001m
err_T=0.1;            % uncertainty of temperature

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 

% some initial adjustments
scrsz = get(0,'ScreenSize');
delete(gcf);
format('long');
% IMIN: variable for communication between uicontrol Callback functions and main function chamberflux_example_final
global IMIN;
IMIN = 0;
% initialisation of manual_discard_start and ...end: -99.9 indicates no
% manual adjustment of discard intervals has been done
manual_discard_start = -99.9;
manual_discard_end = -99.9;

% reading Durbin-watson table (5% significance level: from http://www.stanford.edu/~clint/bench/dwcrit.htm
% for T-K < 90, the Pan, Jie-Jian (1968) method, using code adapted from algorithm AS 153 (AS R52), by R.W. Farebrother (1984).
% for T-K >= 90, the Imhoff, P.J. (1961) method, using code adapted from algorithm AS 256, by R.W. Farebrother (1990).
durbin_watson_table = dlmread('durbin_watson_table.csv');

% Reading header file:
headerdata = dlmread(headerfilename , ',' );

% Counting rows and columns in matrix 'headerdata':
[headerrows,headercolumns] = size(headerdata);

% Display number of rows:
disp(['Header matrix contains: ' num2str(headerrows) ' rows']);

% Convert date from Excel date (1900 = 0) to Matlab date (0 = 0) in seconds:
headerdata = [ round((headerdata(:,1:2)+693960)*86400) headerdata(:,3:headercolumns) ];

% The same for rawdata file:
rawdata = dlmread(rawdatafilename , ',' );  
[rawdatarows,rawdatacolumns] = size(rawdata);
disp(['Rawdata matrix contains: ' num2str(rawdatarows) ' rows']);

rawdata = [ round2n((rawdata(:,timecol)+693960)*86400,-1) rawdata(:,(timecol+1):rawdatacolumns) ];

% The same for metdata file:
metdata = dlmread(metdatafilename , ',' );  
[metdatarows,metdatacolumns] = size(metdata);
disp(['Metdata matrix contains: ' num2str(metdatarows) ' rows']);

metdata = [ round2n((metdata(:,timemetcol)+693960)*86400,-1) metdata(:,(timemetcol+1):metdatacolumns) ];


o=1;

% loop through the rows of the headerfile, ascending order 
i=startrowheader-1;
while 1 == 1;
    i=i+1;
          
    % test if manual adjustment of discard intervals has been taken place, definition of start and end time of flux calculation
    if round2n(manual_discard_start,-1) == -99.9
    startcalc = headerdata(i,1) + str2num(discardstart);
    else
    startcalc = manual_discard_start;
    end
    if round2n(manual_discard_end,-1) == -99.9
    stopcalc = startcalc + str2num(interval);
    else
    stopcalc = manual_discard_end;
    end
    
    % Selection of measurement rows within rawdata for calculation based on start timecol + 'discardstart' & interval length'
    j_calc = find(startcalc <= rawdata(:,timecol) & rawdata(:,timecol) <= stopcalc);
    
    % second test for data availability
    dataavailable = length(j_calc);     
    
    if dataavailable > 0
    calcmatrix = rawdata(min(j_calc):max(j_calc), 1:rawdatacolumns);
    
    % Removing of rawdata rows containing NaNs for calculations
    TF_calc=isnan(calcmatrix);
    calcmatrix_nan_removed=calcmatrix;
    r_calc=0;
    number_NaNs_removed_calc = 0;
    [rows_calcmatrix_nan_removed, columns_calcmatrix_nan_removed] = size(calcmatrix_nan_removed);
    while r_calc <= length(calcmatrix_nan_removed);
        r_calc = r_calc+1;
        TF_calc_nan_removed=isnan(calcmatrix_nan_removed);
        sum_TF=sum(TF_calc_nan_removed(r_calc,:));
        if sum_TF == 0;
            calcmatrix_nan_removed(r_calc,:) = calcmatrix_nan_removed(r_calc,:);
            [rows_calcmatrix_nan_removed, columns_calcmatrix_nan_removed] = size(calcmatrix_nan_removed);
            if r_calc == rows_calcmatrix_nan_removed;
            break
            end
        else
            if r_calc < rows_calcmatrix_nan_removed;
            calcmatrix_nan_removed(r_calc:rows_calcmatrix_nan_removed-1,:) = calcmatrix_nan_removed(r_calc+1:rows_calcmatrix_nan_removed,:);
            N_before=length(calcmatrix_nan_removed(:,1));
            calcmatrix_nan_removed=calcmatrix_nan_removed(1:rows_calcmatrix_nan_removed-1,:);
            else
            calcmatrix_nan_removed(r_calc,:) = [];
            end
            N=length(calcmatrix_nan_removed(:,1));
            number_NaNs_removed_calc = number_NaNs_removed_calc+1;
            [rows_calcmatrix_nan_removed, columns_calcmatrix_nan_removed] = size(calcmatrix_nan_removed);
            if r_calc >= rows_calcmatrix_nan_removed;
            break
            end
            r_calc = r_calc-1   ;        
        end
    end
    disp(['Calculations: Number of rows removed due to NaNs: ' num2str(number_NaNs_removed_calc)]);
    disp(['Number of rows available for calculations: ' num2str(rows_calcmatrix_nan_removed)]);
        
    % Removing of rawdata rows containing zeros or nonplausible values in gas columns for calculations
    calcmatrix_zero_removed=calcmatrix_nan_removed;
    r_calc=0;
    number_zeros_removed_calc = 0;
    [rows_calcmatrix_zero_removed, columns_calcmatrix_zero_removed] = size(calcmatrix_zero_removed);
    while r_calc <= length(calcmatrix_zero_removed);
        r_calc = r_calc+1;
        plausibilitytest=calcmatrix_zero_removed(r_calc,9)*calcmatrix_zero_removed(r_calc,10)*calcmatrix_zero_removed(r_calc,11)*calcmatrix_zero_removed(r_calc,12)*calcmatrix_zero_removed(r_calc,13);
        if calcmatrix_zero_removed(r_calc,gascol) <= min_gas | calcmatrix_zero_removed(r_calc,gascol) >= max_gas | calcmatrix_zero_removed(r_calc,13) <= min_h2o | calcmatrix_zero_removed(r_calc,13) >= max_h2o
            plausibilitytest = 0;
        end            
        if plausibilitytest ~= 0
            calcmatrix_zero_removed(r_calc,:) = calcmatrix_zero_removed(r_calc,:);
            [rows_calcmatrix_zero_removed, columns_calcmatrix_zero_removed] = size(calcmatrix_zero_removed);
            if r_calc == rows_calcmatrix_zero_removed;
            break
            end
        else
            if r_calc < rows_calcmatrix_zero_removed
            calcmatrix_zero_removed(r_calc:rows_calcmatrix_zero_removed-1,:) = calcmatrix_zero_removed(r_calc+1:rows_calcmatrix_zero_removed,:);
            N_before=length(calcmatrix_zero_removed(:,1));
            calcmatrix_zero_removed=calcmatrix_zero_removed(1:rows_calcmatrix_zero_removed-1,:);
            else
            calcmatrix_zero_removed(r_calc,:) = [];
            end
            N=length(calcmatrix_zero_removed(:,1));
            number_zeros_removed_calc = number_zeros_removed_calc+1;
            [rows_calcmatrix_zero_removed, columns_calcmatrix_zero_removed] = size(calcmatrix_zero_removed);
            if r_calc >= rows_calcmatrix_zero_removed;
            break
            end
            r_calc = r_calc-1   ;         
        end
    end
    disp(['Calculations: Number of rows removed due to zeros in gases: ' num2str(number_zeros_removed_calc)]);
    disp(['Number of rows available for calculations: ' num2str(rows_calcmatrix_zero_removed)]);
    
    % Date transformation into seconds from 0 ... end of measurement; if-decision where to set timecol=0...
    % --> mode 0: t=0 at headerdata(i,1)+discardstart; mode 1: t=0 at headerdata(i,1)
    if str2num(mode) == 0
    calcmatrix1 = [round2n(calcmatrix_zero_removed(:,timecol) - calcmatrix_zero_removed(1,timecol),-1)...
                    calcmatrix_zero_removed(:,(timecol+1):rawdatacolumns)];
    else
    calcmatrix1 = [(calcmatrix_zero_removed(:,timecol) - calcmatrix_zero_removed(1,timecol) - (headerdata(i,timecol)- rawdata(min(j_calc),timecol)))...
                    calcmatrix_zero_removed(:,(timecol+1):rawdatacolumns)];  
    end
    
    % watercorrection
    if str2num(watercorrection)==1
        y = calcmatrix1(:,gascol)./(1 - calcmatrix1(:,h2ocol)*conc_unit_factor_h2o)*(1 - calcmatrix1(1,h2ocol)*conc_unit_factor_h2o);
    else
        y = calcmatrix1(:,gascol);
    end
    
    % calculate values without watercorrection
    y_without = calcmatrix1(:,gascol);
   
    % Selection of measurement rows within rawdata for plotting based on start time - 'before' & end time + 'after'
    % this feature is useful for error search (wrong time entries in field book etc.)
    startplot = headerdata(i,1) - str2num(before);
    stopplot = stopcalc + str2num(after);
    
    j_plot = find(startplot <= rawdata(:,timecol) & rawdata(:,timecol) <= stopplot);
    plotmatrix = rawdata(min(j_plot):max(j_plot), 1:rawdatacolumns);
    
    % Removing of rawdata rows containing NaNs for plotting
    TF_plot=isnan(plotmatrix);
    plotmatrix_nan_removed=plotmatrix;
    r_plot=0;
    number_NaNs_removed_plot = 0;
    [rows_plotmatrix_nan_removed, columns_plotmatrix_nan_removed] = size(plotmatrix_nan_removed);
    while r_plot <= length(plotmatrix_nan_removed);
        r_plot = r_plot+1;
        TF_plot_nan_removed=isnan(plotmatrix_nan_removed);
        sum_TF=sum(TF_plot_nan_removed(r_plot,:));
        if sum_TF == 0
            plotmatrix_nan_removed(r_plot,:) = plotmatrix_nan_removed(r_plot,:);
            [rows_plotmatrix_nan_removed, columns_plotmatrix_nan_removed] = size(plotmatrix_nan_removed);
            if r_plot >= rows_plotmatrix_nan_removed
            break
            end
        else
            if r_plot < rows_plotmatrix_nan_removed
            plotmatrix_nan_removed(r_plot:rows_plotmatrix_nan_removed-1,:) = plotmatrix_nan_removed(r_plot+1:rows_plotmatrix_nan_removed,:);
            N_before=length(plotmatrix_nan_removed(:,1));
            plotmatrix_nan_removed=plotmatrix_nan_removed(1:rows_plotmatrix_nan_removed-1,:);
            else
            plotmatrix_nan_removed(r_plot,:) = [];
            end
            N=length(plotmatrix_nan_removed(:,1));
            number_NaNs_removed_plot = number_NaNs_removed_plot+1;
            [rows_plotmatrix_nan_removed, columns_plotmatrix_nan_removed] = size(plotmatrix_nan_removed);
            if r_plot >= rows_plotmatrix_nan_removed;
            break
            end
            r_plot = r_plot-1   ;     
        end
    end
    disp(['Plotting: Number of rows removed due to NaNs: ' num2str(number_NaNs_removed_plot)]);
    disp(['Number of rows available for plotting: ' num2str(rows_plotmatrix_nan_removed)]);
    
    % Removing of rawdata rows containing zeros in gas columns for calculations
    plotmatrix_zero_removed=plotmatrix_nan_removed;
    r_plot=0;
    number_zeros_removed_plot = 0;
    [rows_plotmatrix_zero_removed, columns_plotmatrix_zero_removed] = size(plotmatrix_zero_removed);
    while r_plot <= length(plotmatrix_zero_removed);
        r_plot = r_plot+1;
        plausibilitytest=plotmatrix_zero_removed(r_plot,9)*plotmatrix_zero_removed(r_plot,10)*plotmatrix_zero_removed(r_plot,11)*plotmatrix_zero_removed(r_plot,12)*plotmatrix_zero_removed(r_plot,13);
        if plotmatrix_zero_removed(r_plot,gascol) <= min_gas | plotmatrix_zero_removed(r_plot,gascol) >= max_gas | plotmatrix_zero_removed(r_plot,13) <= min_h2o | plotmatrix_zero_removed(r_plot,13) >= max_h2o
            plausibilitytest = 0;
        end  
        if plausibilitytest ~= 0;
            plotmatrix_zero_removed(r_plot,:) = plotmatrix_zero_removed(r_plot,:);
            [rows_plotmatrix_zero_removed, columns_plotmatrix_zero_removed] = size(plotmatrix_zero_removed);
            if r_plot == rows_plotmatrix_zero_removed;
            break
            end
        else
            if r_plot < rows_plotmatrix_zero_removed
            plotmatrix_zero_removed(r_plot:rows_plotmatrix_zero_removed-1,:) = plotmatrix_zero_removed(r_plot+1:rows_plotmatrix_zero_removed,:);
            N_before=length(plotmatrix_zero_removed(:,1));
            plotmatrix_zero_removed=plotmatrix_zero_removed(1:rows_plotmatrix_zero_removed-1,:);
            else
            plotmatrix_zero_removed(r_plot,:) = [];
            end
            N=length(plotmatrix_zero_removed(:,1));
            number_zeros_removed_plot = number_zeros_removed_plot+1;
            [rows_plotmatrix_zero_removed, columns_plotmatrix_zero_removed] = size(plotmatrix_zero_removed);
            if r_plot >= rows_plotmatrix_zero_removed;
            break
            end
            r_plot = r_plot-1   ;       
        end
    end
    disp(['Plotting: Number of rows removed due to zeros in gases: ' num2str(number_zeros_removed_plot)]);
    disp(['Number of rows available for plotting: ' num2str(rows_plotmatrix_zero_removed)]);
      
    % Date transformation into seconds from before ... after time of measurement; if-decision as for calcmatrix
    if str2num(mode) == 0
    plotmatrix1 = [(plotmatrix_zero_removed(:,timecol) - plotmatrix_zero_removed(1,timecol) - (headerdata(i,1)- rawdata(min(j_plot),timecol))+ (headerdata(i,1)- rawdata(min(j_calc),timecol))), plotmatrix_zero_removed(:,2:rawdatacolumns)];
    else
    plotmatrix1 = [(plotmatrix_zero_removed(:,timecol) - plotmatrix_zero_removed(1,timecol) - (headerdata(i,1)- rawdata(min(j_plot),timecol))), plotmatrix_zero_removed(:,2:rawdatacolumns)];    
    end
           
    % Make datevector of start and end times of experiment
    [year_start, month_start, day_start, hour_start, minute_start, second_start] = datevec(startcalc/86400);
    
    % Selection of measurement rows within metdata based on start timecol + 'discardstart' & interval length   
    if minute_start < 30 & minute_start >= 0;
        timestamp_met = startcalc - minute_start * 60 + 1800 - second_start;
    else
        timestamp_met = startcalc - minute_start * 60 + 3600 - second_start;
    end
    [year_met, month_met, day_met, hour_met, minute_met, second_met] = datevec(metdata(:,timecol)/86400);
    j_met = find(round2n(timestamp_met,0) == round2n((metdata(:,timecol)-second_met),0));
    metdataavailable = length(j_met);     % test for availability of metdata
    metdata_selected = metdata(j_met,:);
    if metdataavailable > 0;
        pressure = metdata_selected(1,metpressurecol);
    else
        pressure = 101.3;
    end

        
    % calculation of mean and standard deviation of supplementary variables
    mean_PAR_all = nanmean(calcmatrix1(:,parcol));
    std_PAR_all = std(calcmatrix1(:,parcol));
    mean_PAR_10first = nanmean(calcmatrix1(1:10,parcol));
    std_PAR_10first = std(calcmatrix1(1:10,parcol));
    mean_Tin_all = nanmean(calcmatrix1(:,tincol));
    std_Tin_all = std(calcmatrix1(:,tincol));
    mean_Tin_10first = nanmean(calcmatrix1(1:10,tincol));
    std_Tin_10first = std(calcmatrix1(1:10,tincol));
    mean_Tsoil_all = nanmean(calcmatrix1(:,tsoilcol));
    std_Tsoil_all = std(calcmatrix1(:,tsoilcol));
    mean_Tsoil_10first = nanmean(calcmatrix1(1:10,tsoilcol));
    std_Tsoil_10first = std(calcmatrix1(1:10,tsoilcol));
    mean_VWC_all = nanmean(calcmatrix1(:,vwccol));
    std_VWC_all = std(calcmatrix1(:,vwccol));
    mean_h2o_all = nanmean(calcmatrix1(:,h2ocol));
    std_h2o_all = std(calcmatrix1(:,h2ocol));
    mean_h2o_10first = nanmean(calcmatrix1(1:10,h2ocol));
    std_h2o_10first = std(calcmatrix1(1:10,h2ocol));
    e_sat_all = 6.03 * 10^((7.45*mean_Tin_all)/(235+mean_Tin_all))/10;  % water saturation pressure in kPa
    e_sat_10first = 6.03 * 10^((7.45*mean_Tin_10first)/(235+mean_Tin_10first))/10; % water saturation pressure in kPa
    VPD_all = e_sat_all - (pressure * mean_h2o_all * conc_unit_factor); % vapour pressure deficit in kPa
    VPD_10first = e_sat_10first - (pressure * mean_h2o_10first * conc_unit_factor); % vapour pressure deficit in kPa
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Start of different linear and nonlinear regression calculations
    
   
    if o == 1;  
    x = calcmatrix1(:,timecol);
 
    else
        x=x_avrg;
        y=y_avrg;
    end
         
    noise = y - y + noise_gas;
    N = length(x);
    tempin=calcmatrix1(1,tincol);

    % number of measurement points
    % Linear regression:
    
    [linear,lineardev,stats] = glmfit(x, y);  % analytical solution of linear regression
   
    % numerical solution of linear regression by nlinfit
        init_lin = [linear(1), linear(2)];
        [fitcoeff_lin, resid_lin, Jacob_lin] = nlinfit(x, y, @polynomial1, init_lin);
        conf_lin_95 = nlparci(fitcoeff_lin, resid_lin, Jacob_lin);
        se_lin = (conf_lin_95(:, 2) - fitcoeff_lin')/tinv(0.975,N-2)*tinv(1-0.16,N-2);
        relerr_lin = abs(se_lin ./ fitcoeff_lin');
        t_lin = abs(fitcoeff_lin(2)/se_lin(2));
        prob_lin = round2n((1-tcdf(t_lin, N-2))*2,-7);
        
        y_lin = fitcoeff_lin(1) + fitcoeff_lin(2)* x;
        SSreg_lin = sum((y_lin - mean(y)).^2);
        SSR_lin = sum(resid_lin.^2);
        SST_lin = sum((y - mean(y)).^2);
        rsq_lin = 1-SSR_lin/SST_lin;
        rsq_lin_adj= 1-(N-1)/(N-2)*(1-rsq_lin);
        
        resStdev_lin = sqrt(SSR_lin/(N-2));
        rmse_lin = sqrt(SSR_lin/N);
        Qx = resStdev_lin/se_lin(2);
        SSR_norm_lin= sum((resid_lin.^2)./(noise.^2));
        chi2_p_lin = chi2cdf(SSR_norm_lin, N-2);
        
        BIC_lin = 2 * log(N) + N * log(SSR_lin/N);
        AICc_lin = 2 * 3 + N * log(SSR_lin/N) + (2*3*(3+1))/(N-3-1);
         
        flux_lin = pressure * 1000 * headerdata(i,volcol) * molmass_gas/...
        (8.314472 * (273.16 + headerdata(i, Tsurfcol)) * area_collar) * fitcoeff_lin(2) * conc_unit_factor * 1000000;
    
        % error propagation for absolute standard error
        flux_lin_abserr=(sqrt((molmass_gas^2*R^-2)*((headerdata(i,volcol)*fitcoeff_lin(2)*area_collar^-1*(273.16+headerdata(i, Tsurfcol))^-1)^2*(err_p*1000)^2+...
            (pressure*1000*fitcoeff_lin(2)*area_collar^-1*(273.16+headerdata(i, Tsurfcol))^-1)^2*err_V^2-...
            (pressure*1000*headerdata(i,volcol)*fitcoeff_lin(2)*area_collar^-2*(273.16+headerdata(i, Tsurfcol))^-1)^2*err_A^2-...
            (pressure*1000*headerdata(i,volcol)*fitcoeff_lin(2)*area_collar^-1*(273.16+headerdata(i, Tsurfcol))^-2)^2*err_T^2+...
            (pressure*1000*headerdata(i,volcol)*area_collar^-1*(273.16+headerdata(i, Tsurfcol))^-1)^2*se_lin(2)^2))) * conc_unit_factor * 1000000;
        flux_lin_relerr = abs(flux_lin_abserr/flux_lin);
       
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        % second Linear regression (for values without watercorrection):
    
    [linear,lineardev,stats] = glmfit(x, y_without);  % analytical solution of linear regression
   
    % numerical solution of linear regression by nlinfit
        init_lin_y_without = [linear(1), linear(2)];
        [fitcoeff_lin_y_without, resid_lin_y_without, Jacob_lin_y_without] = nlinfit(x, y_without, @polynomial1, init_lin_y_without);
        conf_lin_95_y_without = nlparci(fitcoeff_lin_y_without, resid_lin_y_without, Jacob_lin_y_without);
        se_lin_y_without = (conf_lin_95_y_without(:, 2) - fitcoeff_lin_y_without')/tinv(0.975,N-2)*tinv(1-0.16,N-2);
        relerr_lin_y_without = abs(se_lin_y_without ./ fitcoeff_lin_y_without');
        t_lin_y_without = abs(fitcoeff_lin_y_without(2)/se_lin_y_without(2));
        prob_lin_y_without = round2n((1-tcdf(t_lin_y_without, N-2))*2,-7);
        
        y_without_lin = fitcoeff_lin_y_without(1) + fitcoeff_lin_y_without(2)* x;
        SSreg_lin_y_without = sum((y_without_lin - mean(y_without)).^2);
        SSR_lin_y_without = sum(resid_lin_y_without.^2);
        SST_lin_y_without = sum((y_without - mean(y_without)).^2);
        rsq_lin_y_without = 1-SSR_lin/SST_lin;
        rsq_lin_adj_y_witout= 1-(N-1)/(N-2)*(1-rsq_lin_y_without);
        
        resStdev_lin_y_without = sqrt(SSR_lin_y_without/(N-2));
        rmse_lin_y_without = sqrt(SSR_lin_y_without/N);
        Qx = resStdev_lin_y_without/se_lin_y_without(2);
        SSR_norm_lin_y_without= sum((resid_lin_y_without.^2)./(noise.^2));
        chi2_p_lin_y_without = chi2cdf(SSR_norm_lin_y_without, N-2);
        
        BIC_lin_y_without = 2 * log(N) + N * log(SSR_lin_y_without/N);
        AICc_lin_y_without = 2 * 3 + N * log(SSR_lin_y_without/N) + (2*3*(3+1))/(N-3-1);
         
        flux_lin_y_without = pressure * 1000 * headerdata(i,volcol) * molmass_gas/...
        (8.314472 * (273.16 + headerdata(i, Tsurfcol)) * area_collar) * fitcoeff_lin_y_without(2) * conc_unit_factor * 1000000;
    
        % error propagation for absolute standard error
        flux_lin_abserr_y_without=(sqrt((molmass_gas^2*R^-2)*((headerdata(i,volcol)*fitcoeff_lin_y_without(2)*area_collar^-1*(273.16+headerdata(i, Tsurfcol))^-1)^2*(err_p*1000)^2+...
            (pressure*1000*fitcoeff_lin_y_without(2)*area_collar^-1*(273.16+headerdata(i, Tsurfcol))^-1)^2*err_V^2-...
            (pressure*1000*headerdata(i,volcol)*fitcoeff_lin_y_without(2)*area_collar^-2*(273.16+headerdata(i, Tsurfcol))^-1)^2*err_A^2-...
            (pressure*1000*headerdata(i,volcol)*fitcoeff_lin_y_without(2)*area_collar^-1*(273.16+headerdata(i, Tsurfcol))^-2)^2*err_T^2+...
            (pressure*1000*headerdata(i,volcol)*area_collar^-1*(273.16+headerdata(i, Tsurfcol))^-1)^2*se_lin_y_without(2)^2))) * conc_unit_factor * 1000000;
        flux_lin_relerr_y_without = abs(flux_lin_abserr_y_without/flux_lin_y_without);
        
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            
    % Polynomial regression free
    
    % 2nd order using polyfit
    [p2, S2] = polyfit(x,y,2);
    pol2 = polyval(p2,x,S2);
    resid_pol2a = y - pol2;
    SSR_pol2a = sum(resid_pol2a.^2);
    SSR_norm_pol2a = sum((resid_pol2a.^2)./(noise.^2));
    chi2_p_pol2a = chi2cdf(SSR_norm_pol2a, N-3); % should be below 0.05
    BIC_pol2a = 3 * log(N) + N * log(SSR_pol2a/N);
    AICc_pol2a = 2 * 4 + N * log(SSR_pol2a/N) + (2*4*(4+1))/(N-4-1);
    
    % 2nd order polynomial using nlinfit
    init_pol2 = [p2(3), p2(2), p2(1)];
    [fitcoeff_pol2, resid_pol2, Jacob_pol2] = nlinfit(x, y, @polynomial2, init_pol2);
    
        % confidence, error and R2 estimation
        conf_pol2_95 = nlparci(fitcoeff_pol2, resid_pol2, Jacob_pol2);
        se_pol2 = (conf_pol2_95(:, 2) - fitcoeff_pol2')/tinv(0.975,N-3)*tinv(1-0.16,N-3);
        relerr_pol2 = abs(se_pol2 ./ fitcoeff_pol2');
        t_pol2 = abs(fitcoeff_pol2(2)/se_pol2(2));
        prob_pol2 = round2n((1-tcdf(t_pol2, N-3))*2,-7);
        
    
        y_pol2 = polynomial2(fitcoeff_pol2, x);
        SSreg_pol2 = sum((y_pol2 - mean(y)).^2);
        SSR_pol2 = sum(resid_pol2.^2);
        SST_pol2 = sum((y - mean(y)).^2);
        rsq_pol2 = 1 - SSR_pol2/SST_pol2;
        rsq_pol2_adj= 1-(N-1)/(N-3)*(1-rsq_pol2);
        
        resStdev_pol2 = sqrt(SSR_pol2/(N-3));
        rmse_pol2 = sqrt(SSR_pol2/N);
        SSR_norm_pol2= sum((resid_pol2.^2)./(noise.^2));
        chi2_p_pol2 = chi2cdf(SSR_norm_pol2, N-3); % should be below 0.05
        
        BIC_pol2 = 3 * log(N) + N * log(SSR_pol2/N);
        AICc_pol2 = 2 * 4 + N * log(SSR_pol2/N) + (2*4*(4+1))/(N-4-1);

        flux_pol2 = pressure*1000 * headerdata(i,volcol) * molmass_gas/...
        (8.314472 * (273.16 + headerdata(i, Tsurfcol)) * area_collar) * fitcoeff_pol2(2) * conc_unit_factor * 1000000;
    
        % error propagation for absolute standard error
        flux_pol2_abserr=(sqrt((molmass_gas^2*R^-2)*((headerdata(i,volcol)*fitcoeff_pol2(2)*area_collar^-1*(273.16+headerdata(i, Tsurfcol))^-1)^2*(err_p*1000)^2+...
            (pressure*1000*fitcoeff_pol2(2)*area_collar^-1*(273.16+headerdata(i, Tsurfcol))^-1)^2*err_V^2-...
            (pressure*1000*headerdata(i,volcol)*fitcoeff_pol2(2)*area_collar^-2*(273.16+headerdata(i, Tsurfcol))^-1)^2*err_A^2-...
            (pressure*1000*headerdata(i,volcol)*fitcoeff_pol2(2)*area_collar^-1*(273.16+headerdata(i, Tsurfcol))^-2)^2*err_T^2+...
            (pressure*1000*headerdata(i,volcol)*area_collar^-1*(273.16+headerdata(i, Tsurfcol))^-1)^2*se_pol2(2)^2))) * conc_unit_factor * 1000000;
        flux_pol2_relerr = abs(flux_pol2_abserr/flux_pol2);
        devfac_pol2 = flux_pol2/flux_lin;
        
        
    % 3rd order polynomial using polyfit
    [p3, S3] = polyfit(x,y,3);
    pol3 = polyval(p3,x,S3);
    resid_pol3a = y -pol3;
    SSR_pol3a = sum(resid_pol3a.^2);
    SSR_norm_pol3a = sum((resid_pol3a.^2)./(noise.^2));
    chi2_p_pol3a = chi2cdf(SSR_norm_pol3a, N-4); % should be below 0.05
    BIC_pol3a = 4 * log(N) + N * log(SSR_pol3a/N);
    AICc_pol3a = 2 * 5 + N * log(SSR_pol3a/N) + (2*5*(5+1))/(N-5-1);
    
    % 3rd order polynomial using nlinfit
    init_pol3 = [p3(4), p3(3), p3(2), p3(1)];
    [fitcoeff_pol3, resid_pol3, Jacob_pol3] = nlinfit(x, y, @polynomial3, init_pol3);
     % confidence, error and R2 estimation
        conf_pol3_95 = nlparci(fitcoeff_pol3, resid_pol3, Jacob_pol3);
        se_pol3 = (conf_pol3_95(:, 2) - fitcoeff_pol3')/tinv(0.975,N-4)*tinv(1-0.16,N-4);
        relerr_pol3 = abs(se_pol3 ./ fitcoeff_pol3');
        t_pol3 = abs(fitcoeff_pol3(2)/se_pol3(2));
        prob_pol3 = round2n((1-tcdf(t_pol3, N-4))*2,-7);
    
        y_pol3 = polynomial3(fitcoeff_pol3, x);
        SSreg_pol3 = sum((y_pol3 - mean(y)).^2);
        SSR_pol3 = sum(resid_pol3.^2);
        SST_pol3 = sum((y - mean(y)).^2);
        rsq_pol3 = 1 - SSR_pol3/SST_pol3;
        rsq_pol3_adj= 1-(N-1)/(N-4)*(1-rsq_pol3);
        
        resStdev_pol3 = sqrt(SSR_pol3/(N-4));
        rmse_pol3 = sqrt(SSR_pol3/N);
        SSR_norm_pol3= sum((resid_pol3.^2)./(noise.^2));
        chi2_p_pol3 = chi2cdf(SSR_norm_pol3, N-4); % should be below 0.05
        
        BIC_pol3 = 4 * log(N) + N * log(SSR_pol3/N);
        AICc_pol3 = 2 * 5 + N * log(SSR_pol3/N) + (2*5*(5+1))/(N-5-1);


        flux_pol3 = pressure*1000 * headerdata(i,volcol) * molmass_gas/...
        (8.314472 * (273.16 + headerdata(i, Tsurfcol)) * area_collar) * fitcoeff_pol3(2) * conc_unit_factor * 1000000;
    
        % error propagation for absolute standard error
        flux_pol3_abserr=(sqrt((molmass_gas^2*R^-2)*((headerdata(i,volcol)*fitcoeff_pol3(2)*area_collar^-1*(273.16+headerdata(i, Tsurfcol))^-1)^2*(err_p*1000)^2+...
            (pressure*1000*fitcoeff_pol3(2)*area_collar^-1*(273.16+headerdata(i, Tsurfcol))^-1)^2*err_V^2-...
            (pressure*1000*headerdata(i,volcol)*fitcoeff_pol3(2)*area_collar^-2*(273.16+headerdata(i, Tsurfcol))^-1)^2*err_A^2-...
            (pressure*1000*headerdata(i,volcol)*fitcoeff_pol3(2)*area_collar^-1*(273.16+headerdata(i, Tsurfcol))^-2)^2*err_T^2+...
            (pressure*1000*headerdata(i,volcol)*area_collar^-1*(273.16+headerdata(i, Tsurfcol))^-1)^2*se_pol3(2)^2))) * conc_unit_factor * 1000000;
        flux_pol3_relerr = abs(flux_pol3_abserr/flux_pol3);
        devfac_pol3 = flux_pol3/flux_lin;
        
        
   %Loop for searching best polynom
   m=0;
   order = 0;
   order_bad_condition = [NaN, NaN, NaN];
   BIC_before1 = (N - (order+1)) * log(N) + N * log(sum((y - mean(y)).^2)/N);
   AICc_before1 = 2 * (order+1+1) + N * log(sum((y - mean(y)).^2)/N) + (2*(order+1+1)*((order+1+1)+1))/(N-(order+1+1)-1);
   order_before1 = 0 ;
   lastwarn('1');
   while 1<3
       order=order+1;
       [p,S] = polyfit(x,y,order);
       if strcmp('1', lastwarn) == 0 
       m=m+1;
       order_bad_condition(m) = order;
       %     breakreason = 'Polynomial badly conditioned'
       %     break
       end
       [polfun, delta] = polyval(p,x,S);
       resid_poly = y - polfun;
       SSR_poly = sum(resid_poly.^2);
       BIC_poly = (order+1) * log(N) + N * log(SSR_poly/N);
       AICc_poly = 2 * (order+1+1) + N * log(SSR_poly/N) + (2*(order+1+1)*((order+1+1)+1))/(N-(order+1+1)-1);
       if BIC_poly > BIC_before1 %BIC is not a continuous function of the order; therefore check of order=order+1
           order=order+1;
           [p,S] = polyfit(x,y,order);
           if strcmp('1', lastwarn) == 0
           m=m+1;
           order_bad_condition(m) = order;
           end
           [polfun, delta] = polyval(p,x,S);
           resid_poly = y - polfun;
           SSR_poly = sum(resid_poly.^2);
           BIC_poly = (order+1) * log(N) + N * log(SSR_poly/N);
           AICc_poly = 2 * (order+1+1) + N * log(SSR_poly/N) + (2*(order+1+1)*((order+1+1)+1))/(N-(order+1+1)-1);
           if BIC_poly > BIC_before1
           breakreason = 'BIC degraded';
           break
           end
       end
       BIC_before1 = BIC_poly;
       AICc_before1 = AICc_poly;
       p_before1 = p;
       S_before1 = S;
       order_before1 = order;
       warnmsg_test = str2num(lastwarn);
   end
     
       %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     % Nonlinear regression with power series expansion of exponential function 17th order
    
    init_powser = [linear(1), linear(2), fitcoeff_pol2(3)];
    % 7th order power series expansion of exponential function
    [fitcoeff_powser17, resid_powser17, Jacob_powser17] = nlinfit(x, y, @powerseriesexpansion17, init_powser);
    % confidence, error and R2 estimation
    conf_powser17_95 = nlparci(fitcoeff_powser17, resid_powser17, Jacob_powser17);
    se_powser17 = (conf_powser17_95(:, 2) - fitcoeff_powser17')/tinv(0.975,N-3)*tinv(1-0.16,N-3);
    relerr_powser17 = abs(se_powser17 ./ fitcoeff_powser17');
    t_powser17 = abs(fitcoeff_powser17(2)/se_powser17(2));
    prob_powser17 = round2n((1-tcdf(t_powser17, N-3))*2,-7) ;   
          
    y_powser17 = powerseriesexpansion17(fitcoeff_powser17, x);
        SSreg_powser17 = sum((y_powser17 - mean(y)).^2);
        SSR_powser17 = sum(resid_powser17.^2);
        SST_powser17 = sum((y - mean(y)).^2);
        rsq_powser17 = 1 - SSR_powser17/SST_powser17;
        rsq_powser17_adj= 1-(N-1)/(N-3)*(1-rsq_powser17);
       
        resStdev_powser17 = sqrt(SSR_powser17/(N-3));
        rmse_powser17 = sqrt(SSR_powser17/N);
        SSR_norm_powser17= sum((resid_powser17.^2)./(noise.^2));
        chi2_p_powser17 = chi2cdf(SSR_norm_powser17, N-3); % should be below 0.05
        
        BIC_powser17 = 3 * log(N) + N * log(SSR_powser17/N);
        AICc_powser17 = 2 * 4 + N * log(SSR_powser17/N) + (2*4*(4+1))/(N-4-1);


        flux_powser17 = pressure*1000 * headerdata(i,volcol) * molmass_gas/...
        (8.314472 * (273.16 + headerdata(i, Tsurfcol)) * area_collar) * fitcoeff_powser17(2) * conc_unit_factor * 1000000;
             
        flux_powser17_abserr=(sqrt((molmass_gas^2*R^-2)*((headerdata(i,volcol)*fitcoeff_powser17(2)*area_collar^-1*(273.16+headerdata(i, Tsurfcol))^-1)^2*(err_p*1000)^2+...
            (pressure*1000*fitcoeff_powser17(2)*area_collar^-1*(273.16+headerdata(i, Tsurfcol))^-1)^2*err_V^2-...
            (pressure*1000*headerdata(i,volcol)*fitcoeff_powser17(2)*area_collar^-2*(273.16+headerdata(i, Tsurfcol))^-1)^2*err_A^2-...
            (pressure*1000*headerdata(i,volcol)*fitcoeff_powser17(2)*area_collar^-1*(273.16+headerdata(i, Tsurfcol))^-2)^2*err_T^2+...
            (pressure*1000*headerdata(i,volcol)*area_collar^-1*(273.16+headerdata(i, Tsurfcol))^-1)^2*se_powser17(2)^2))) * conc_unit_factor * 1000000;
        flux_powser17_relerr = abs(flux_powser17_abserr/flux_powser17);
        devfac_powser17 = flux_powser17/flux_lin;  
   
    try  
    error_occured_exp = 0; 
    initexp = [fitcoeff_powser17(1) - (fitcoeff_powser17(2)^2)/(2*fitcoeff_powser17(3)), (fitcoeff_powser17(2)^2)/(2*fitcoeff_powser17(3)), 2*fitcoeff_powser17(3)/fitcoeff_powser17(2)];
    %  exponential regression
    [fitcoeff_exp, resid_exp, Jacob_exp] = nlinfit(x, y, @exponential, initexp);
    % confidence and error estimation
    conf_exp_95 = nlparci(fitcoeff_exp, resid_exp, Jacob_exp);
    se_exp = (conf_exp_95(:, 2) - fitcoeff_exp')/tinv(0.975,N-3)*tinv(1-0.16,N-3);
    relerr_exp = abs(se_exp ./ fitcoeff_exp');
        
    y_exp = exponential(fitcoeff_exp, x);
        SSreg_exp = sum((y_exp - mean(y)).^2);
        SSR_exp = sum(resid_exp.^2);
        SST_exp = sum((y - mean(y)).^2);
        rsq_exp = 1 - SSR_exp/SST_exp;
        rsq_exp_adj= 1-(N-1)/(N-3)*(1-rsq_exp);
        
        resStdev_exp = sqrt(SSR_exp/(N-3));
        rmse_exp = sqrt(SSR_exp/N);
        SSR_norm_exp= sum((resid_exp.^2)./(noise.^2));
        chi2_p_exp = chi2cdf(SSR_norm_exp, N-3); % should be below 0.05
        
        BIC_exp = 3 * log(N) + N * log(SSR_exp/N);
        AICc_exp = 2 * 4 + N * log(SSR_exp/N) + (2*4*(4+1))/(N-4-1);
        
        offset_exp = fitcoeff_exp(1) + fitcoeff_exp(2);
        abserr_offset_exp = sqrt(se_exp(1)^2 + se_exp(2)^2);
        relerr_offset_exp = abs(abserr_offset_exp/offset_exp);
        
        slope_exp = fitcoeff_exp(2) * fitcoeff_exp(3);
        abserr_slope_exp = sqrt((fitcoeff_exp(3) * se_exp(2))^2 + (fitcoeff_exp(2) * se_exp(3))^2);
        relerr_slope_exp = abs(abserr_slope_exp/slope_exp);
        t_exp = abs(slope_exp/abserr_slope_exp);
        prob_exp = round2n((1-tcdf(t_exp, N-3))*2,-7);

        flux_exp = pressure*1000 * headerdata(i,volcol) * molmass_gas/...
        (8.314472 * (273.16 + headerdata(i, Tsurfcol)) * area_collar) * slope_exp * conc_unit_factor * 1000000;

     flux_exp_abserr=(sqrt((molmass_gas^2*R^-2)*((headerdata(i,volcol)*slope_exp*area_collar^-1*(273.16+headerdata(i, Tsurfcol))^-1)^2*(err_p*1000)^2+...
            (pressure*1000*slope_exp*area_collar^-1*(273.16+headerdata(i, Tsurfcol))^-1)^2*err_V^2-...
            (pressure*1000*headerdata(i,volcol)*slope_exp*area_collar^-2*(273.16+headerdata(i, Tsurfcol))^-1)^2*err_A^2-...
            (pressure*1000*headerdata(i,volcol)*slope_exp*area_collar^-1*(273.16+headerdata(i, Tsurfcol))^-2)^2*err_T^2+...
            (pressure*1000*headerdata(i,volcol)*area_collar^-1*(273.16+headerdata(i, Tsurfcol))^-1)^2*abserr_slope_exp^2))) * conc_unit_factor * 1000000;
        flux_exp_relerr = abs(flux_exp_abserr/flux_exp);
        devfac_exp = flux_exp/flux_lin;  
    
    catch   
    error_occured_exp = 1;
    fitcoeff_exp=[-9999,-9999,-9999]; 
    se_exp(1) =-9999;
    relerr_exp(1) =-9999;
    se_exp(2) =-9999;
    relerr_exp(2) =-9999;
    se_exp(3) =-9999;
    relerr_exp(3) =-9999;
    t_exp =-9999;
    prob_exp =-9999;
    rsq_exp = -9999;
    rsq_exp_adj= -9999;
    SSR_exp =-9999;
    resStdev_exp =-9999;
    rmse_exp = -9999;
    SSR_norm_exp= -9999;
    chi2_p_exp = -9999;     
    BIC_exp = -9999;
    AICc_exp = -9999;
    flux_exp = -9999;
    flux_exp_abserr = -9999;
    flux_exp_relerr = -9999;
    offset_exp = -9999;
    abserr_offset_exp = -9999;
    relerr_offset_exp = -9999;        
    slope_exp = -9999;
    abserr_slope_exp = -9999;
    relerr_slope_exp = -9999;
    t_exp = -9999;
    prob_exp = -9999;
    devfac_exp = -9999;
    resid_exp(1:N-1)=-9999;
    resid_exp=-9999;
    end
        
  
   
   %T-test significance of difference between slopes of lin and powser17
     diff_slopes=abs(linear(2)-fitcoeff_powser17(2)); 
     errorestim_diff_slopes=sqrt(stats.se(2)^2+se_powser17(2)^2);
     t_diff_slopes = diff_slopes/errorestim_diff_slopes;
     c = se_powser17(2)^2/(stats.se(2)^2+se_powser17(2)^2);
     fg = 1/(c^2/(N-3)+(1-c)^2/(N-2));
     prob_diff = round2n((1-tcdf(t_diff_slopes, fg))*2,-7);
    
    try    
    if 1==1
    error_occured_living = 0;      
    init_living = [360,0.1,10000];
 
    [fitcoeff_living, resid_living, Jacob_living] = nlinfit(x, y, @living, init_living);
    conf_living_95 = nlparci(fitcoeff_living, resid_living, Jacob_living);
    se_living = (conf_living_95(:, 2) - fitcoeff_living')/tinv(0.975,N-3)*tinv(1-0.16,N-3);
    relerr_living = abs(se_living ./ fitcoeff_living');
    t_living = abs(fitcoeff_living(2)/se_living(2));
    prob_living = round2n((1-tcdf(t_living, N-3))*2,-7);
    
    y_living = exponential(fitcoeff_living, x);
        SSreg_living = sum((y_living - mean(y)).^2);
        SSR_living = sum(resid_living.^2);
        SST_living = sum((y - mean(y)).^2);
        rsq_living = 1 - SSR_living/SST_living;
        rsq_living_adj= 1-(N-1)/(N-3)*(1-rsq_living);
        
        resStdev_living = sqrt(SSR_living/(N-3));
        rmse_living = sqrt(SSR_living/N);
        SSR_norm_living= sum((resid_living.^2)./(noise.^2));
        chi2_p_living = chi2cdf(SSR_norm_living, N-3); % should be below 0.05
        
        BIC_living = 3 * log(N) + N * log(SSR_living/N);
        AICc_living = 2 * 4 + N * log(SSR_living/N) + (2*4*(4+1))/(N-4-1);


        flux_living = pressure*1000 * headerdata(i,volcol) * molmass_gas/...
        (8.314472 * (273.16 + headerdata(i, Tsurfcol)) * area_collar) * fitcoeff_living(2) * conc_unit_factor * 1000000;

        flux_living_abserr=(sqrt((molmass_gas^2*R^-2)*((headerdata(i,volcol)*fitcoeff_living(2)*area_collar^-1*(273.16+headerdata(i, Tsurfcol))^-1)^2*(err_p*1000)^2+...
            (pressure*1000*fitcoeff_living(2)*area_collar^-1*(273.16+headerdata(i, Tsurfcol))^-1)^2*err_V^2-...
            (pressure*1000*headerdata(i,volcol)*fitcoeff_living(2)*area_collar^-2*(273.16+headerdata(i, Tsurfcol))^-1)^2*err_A^2-...
            (pressure*1000*headerdata(i,volcol)*fitcoeff_living(2)*area_collar^-1*(273.16+headerdata(i, Tsurfcol))^-2)^2*err_T^2+...
            (pressure*1000*headerdata(i,volcol)*area_collar^-1*(273.16+headerdata(i, Tsurfcol))^-1)^2*se_living(2)^2))) * conc_unit_factor * 1000000;
        flux_living_relerr = abs(flux_living_abserr/flux_living);
        devfac_living = flux_living/flux_lin;

       
    end
    
    catch
    error_occured_living = 1;
    fitcoeff_living=[-9999,-9999,-9999]; 
    se_living(1) =-9999;
    relerr_living(1) =-9999;
    se_living(2) =-9999;
    relerr_living(2) =-9999;
    se_living(3) =-9999;
    relerr_living(3) =-9999;
    t_living =-9999;
    prob_living =-9999;
    rsq_living = -9999;
    rsq_living_adj= -9999;
    SSR_living =-9999;
    resStdev_living =-9999;
    rmse_living = -9999;
    SSR_norm_living= -9999;
    chi2_p_living = -9999;     
    BIC_living = -9999;
    AICc_living = -9999;
    flux_living = -9999;
    flux_living_abserr = -9999;
    devfac_living = -9999;
    resid_living(1:N-1)=-9999;
    resid_living=-9999;
       
    end
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     
    %%%%%test if flux by powser17 = flux by exp
    if abs((flux_powser17-flux_exp)/flux_exp) > 0.01
        error_powser17 = 1;
    else
        error_powser17 = 0;
    end
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     %  F test linear - nonlinear
        
      P_Var_kleiner_lin=1-fcdf(sum(resid_lin(:,1).^2)/sum(resid_lin(:,1).^2),N-1-2,N-1-2);
      P_Var_kleiner_pol2=1-fcdf(sum(resid_lin(:,1).^2)/sum(resid_pol2(:,1).^2),N-1-2,N-1-3);
      P_Var_kleiner_pol3=1-fcdf(sum(resid_lin(:,1).^2)/sum(resid_pol3(:,1).^2),N-1-2,N-1-4);
      try
      P_Var_kleiner_exp=1-fcdf(sum(resid_lin(:,1).^2)/sum(resid_exp(:,1).^2),N-1-2,N-1-3);
      catch
      lasterr= lasterror;
      lasterr.message
      P_Var_kleiner_exp=-9999;
      end   
      P_Var_kleiner_powser17=1-fcdf(sum(resid_lin(:,1).^2)/sum(resid_powser17(:,1).^2),N-1-2,N-1-3);
      try
      P_Var_kleiner_living=1-fcdf(sum(resid_lin(:,1).^2)/sum(resid_living(:,1).^2),N-1-2,N-1-3);
      catch 
      lasterr= lasterror;
      lasterr.message
      P_Var_kleiner_living=-9999;
      end
      
      P_Var_kleiner_powser17alspol2=1-fcdf(sum(resid_pol2(:,1).^2)/sum(resid_powser17(:,1).^2),N-1-3,N-1-3);
      devfac_powser17zupol2 = flux_powser17/flux_pol2;
      try
      P_Var_kleiner_livingalspowser17=1-fcdf(sum(resid_powser17(:,1).^2)/sum(resid_living(:,1).^2),N-1-3,N-1-3);
      catch 
      lasterr= lasterror
      lasterr.message
      P_Var_kleiner_livingalspowser17=-9999;
      end
      devfac_powser17zupol2 = flux_powser17/flux_pol2;
      devfac_livingzupowser17=flux_living/flux_powser17;
      
   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%   
   
   
   if 1==1
  error_occured_combined = 0;     
  try
  init_combined = [450, -130, -0.003, 4000, 72];
    %%% Check if degrees of freedom are here correct!!! Area of
    %%% construction!
   [fitcoeff_combined, resid_combined, Jacob_combined] = nlinfit(x, y, @combined, init_combined);
   global fitcoeff_combined4
   global fitcoeff_combined5
   fitcoeff_combined4=fitcoeff_combined(4);
   fitcoeff_combined5=fitcoeff_combined(5);
   init_powser17_combined = [linear(1), linear(2),0];
   
   [fitcoeff_powser17_comb, resid_powser17_comb, Jacob_powser17_comb] = nlinfit(x, y, @powerseriesexpansion17_combined, init_powser17_combined); 
    conf_powser17_comb_95 = nlparci(fitcoeff_powser17_comb, resid_powser17_comb, Jacob_powser17_comb);
    se_powser17_comb = (conf_powser17_comb_95(:, 2) - fitcoeff_powser17_comb')/tinv(0.975,N-3)*tinv(1-0.16,N-3);
    relerr_powser17_comb = abs(se_powser17_comb ./ fitcoeff_powser17_comb');
      
    y_powser17_comb = powerseriesexpansion17_combined(fitcoeff_powser17_comb, x);
        SSreg_powser17_comb = sum((y_powser17_comb - mean(y)).^2);
        SSR_powser17_comb = sum(resid_powser17_comb.^2);
        SST_powser17_comb = sum((y - mean(y)).^2);
        rsq_powser17_comb = 1 - SSR_powser17_comb/SST_powser17_comb;
        rsq_powser17_comb_adj= 1-(N-1)/(N-3)*(1-rsq_powser17_comb);
        
        resStdev_powser17_comb = sqrt(SSR_powser17_comb/(N-3));
        rmse_powser17_comb = sqrt(SSR_powser17_comb/N);
        SSR_norm_powser17_comb= sum((resid_powser17_comb.^2)./(noise.^2));
        chi2_p_powser17_comb = chi2cdf(SSR_norm_powser17_comb, N-3); % should be below 0.05
        
        BIC_powser17_comb = 3 * log(N) + N * log(SSR_powser17_comb/N);
        AICc_powser17_comb = 2 * 3 + N * log(SSR_powser17_comb/N) + (2*3*(3+1))/(N-3-1);
   
   
   xtest=min(x):0.1:max(x);
   y_powser_combined = powerseriesexpansion17_combined(fitcoeff_powser17_comb, xtest)';
   length(y_powser_combined);
   for p = 3:length(y_powser_combined)
       if (abs(powerseriesexpansion17_combined(fitcoeff_powser17_comb, xtest(p))-powerseriesexpansion17_combined(fitcoeff_powser17_comb, xtest(p-1))))< abs((powerseriesexpansion17_combined(fitcoeff_powser17_comb, xtest(p-1))-powerseriesexpansion17_combined(fitcoeff_powser17_comb, xtest(p-2))));
         break
       end
   end
      wendepunkt=xtest(p-1);
      wendepunktssteigung = ((powerseriesexpansion17_combined(fitcoeff_powser17_comb, xtest(p))-powerseriesexpansion17_combined(fitcoeff_powser17_comb, xtest(p-1))) + (powerseriesexpansion17_combined(fitcoeff_powser17_comb, xtest(p-1))-powerseriesexpansion17_combined(fitcoeff_powser17_comb, xtest(p-2))))/2;
   
  catch
     error_occured_combined = 1;
     fitcoeff_powser17_comb(1) = -9999;
     se_powser17_comb(1) = -9999;
     relerr_powser17_comb(1) = -9999;
     fitcoeff_powser17_comb(2) = -9999;
     se_powser17_comb(2) = -9999;
     relerr_powser17_comb(2) = -9999;
     fitcoeff_powser17_comb(3) = -9999;
     se_powser17_comb(3) = -9999;
     relerr_powser17_comb(3) = -9999;
     fitcoeff_combined(4) = -9999;
     fitcoeff_combined(5) = -9999;
     wendepunkt = -9999;
     wendepunktssteigung = -9999;
     rsq_powser17_comb = -9999;
     rsq_powser17_comb_adj = -9999;
     SSR_powser17_comb = -9999;
     resStdev_powser17_comb = -9999;
     rmse_powser17_comb = -9999;
     SSR_norm_powser17_comb = -9999;
     chi2_p_powser17_comb = -9999;
     BIC_powser17_comb = -9999;
     AICc_powser17_comb = -9999 ;
  end
          
   end
   
   
    % if-loops for different ranges of Durbin-Watson table, different parameter numbers
        % 2 Parameter
        if N <= 200 % range 6...200: interval 1
            k = find(N == durbin_watson_table(:,1) & durbin_watson_table(:,2) == 2);
            dL_2P = durbin_watson_table(k, 3);
            dU_2P = durbin_watson_table(k, 4);
        elseif N <=500 % range 200...500: interval 10
            k = find((N-9) <= durbin_watson_table(:,1) & (N+9) >= durbin_watson_table(:,1) & ...
                durbin_watson_table(:,2) == 2);
            if length(k) == 1
                dL_2P = durbin_watson_table(k, 3);
                dU_2P = durbin_watson_table(k, 4);
            elseif length(k) > 1
              dL_2P = durbin_watson_table(k(length(k)-1), 3) + (durbin_watson_table(k(length(k)), 3) ...
                  - durbin_watson_table(k(length(k)-1), 3))/10 * (N - durbin_watson_table(k(length(k)-1), 1));
              dU_2P = durbin_watson_table(k(length(k)-1), 4) + (durbin_watson_table(k(length(k)), 4) ...
                  - durbin_watson_table(k(length(k)-1), 4))/10 * (N - durbin_watson_table(k(length(k)-1), 1));
            end
        elseif N <= 2000 % range 500...2000: interval 50
            k = find((N-49) <= durbin_watson_table(:,1) & (N+49) >= durbin_watson_table(:,1) & ...
                durbin_watson_table(:,2) == 2);
           if length(k) == 1
                dL_2P = durbin_watson_table(k, 3);
                dU_2P = durbin_watson_table(k, 4);
           elseif length(k) > 1
              dL_2P = durbin_watson_table(k(length(k)-1), 3) + (durbin_watson_table(k(length(k)), 3) ...
                  - durbin_watson_table(k(length(k)-1), 3))/10 * (N - durbin_watson_table(k(length(k)-1), 1));
              dU_2P = durbin_watson_table(k(length(k)-1), 4) + (durbin_watson_table(k(length(k)), 4) ...
                  - durbin_watson_table(k(length(k)-1), 4))/10 * (N - durbin_watson_table(k(length(k)-1), 1));
           end
        else % greater than 2000 undefined
           dL_2P = NaN;
           dU_2P = NaN;
        end 
    
                
        % 3 Parameter
        if N <= 200 % range 6...200: interval 1
            k = find(N == durbin_watson_table(:,1) & durbin_watson_table(:,2) == 3);
            dL_3P = durbin_watson_table(k, 3);
            dU_3P = durbin_watson_table(k, 4);
        elseif N <=500 % range 200...500: interval 10
            k = find((N-9) <= durbin_watson_table(:,1) & (N+9) >= durbin_watson_table(:,1) & ...
                durbin_watson_table(:,2) == 3);
            if length(k) == 1
                dL_3P = durbin_watson_table(k, 3);
                dU_3P = durbin_watson_table(k, 4);
            elseif length(k) > 1
              dL_3P = durbin_watson_table(k(length(k)-1), 3) + (durbin_watson_table(k(length(k)), 3) ...
                  - durbin_watson_table(k(length(k)-1), 3))/10 * (N - durbin_watson_table(k(length(k)-1), 1));
              dU_3P = durbin_watson_table(k(length(k)-1), 4) + (durbin_watson_table(k(length(k)), 4) ...
                  - durbin_watson_table(k(length(k)-1), 4))/10 * (N - durbin_watson_table(k(length(k)-1), 1));
            end
        elseif N <= 2000 % range 500...2000: interval 50
            k = find((N-49) <= durbin_watson_table(:,1) & (N+49) >= durbin_watson_table(:,1) & ...
                durbin_watson_table(:,2) == 3);
           if length(k) == 1
                dL_3P = durbin_watson_table(k, 3);
                dU_3P = durbin_watson_table(k, 4);
           elseif length(k) > 1
              dL_3P = durbin_watson_table(k(length(k)-1), 3) + (durbin_watson_table(k(length(k)), 3) ...
                  - durbin_watson_table(k(length(k)-1), 3))/10 * (N - durbin_watson_table(k(length(k)-1), 1));
              dU_3P = durbin_watson_table(k(length(k)-1), 4) + (durbin_watson_table(k(length(k)), 4) ...
                  - durbin_watson_table(k(length(k)-1), 4))/10 * (N - durbin_watson_table(k(length(k)-1), 1));
           end
        else % greater than 2000 undefined
           dL_3P = NaN;
           dU_3P = NaN;
        end 
      
        
        % 4 Parameter
        if N <= 200 % range 6...200: interval 1
            k = find(N == durbin_watson_table(:,1) & durbin_watson_table(:,2) == 4);
            dL_4P = durbin_watson_table(k, 3);
            dU_4P = durbin_watson_table(k, 4);
        elseif N <=500 % range 200...500: interval 10
            k = find((N-9) <= durbin_watson_table(:,1) & (N+9) >= durbin_watson_table(:,1) & ...
                durbin_watson_table(:,2) == 4);
            if length(k) == 1
                dL_4P = durbin_watson_table(k, 3);
                dU_4P = durbin_watson_table(k, 4);
            elseif length(k) > 1
              dL_4P = durbin_watson_table(k(length(k)-1), 3) + (durbin_watson_table(k(length(k)), 3) ...
                  - durbin_watson_table(k(length(k)-1), 3))/10 * (N - durbin_watson_table(k(length(k)-1), 1));
              dU_4P = durbin_watson_table(k(length(k)-1), 4) + (durbin_watson_table(k(length(k)), 4) ...
                  - durbin_watson_table(k(length(k)-1), 4))/10 * (N - durbin_watson_table(k(length(k)-1), 1));
            end
        elseif N <= 2000 % range 500...2000: interval 50
            k = find((N-49) <= durbin_watson_table(:,1) & (N+49) >= durbin_watson_table(:,1) & ...
                durbin_watson_table(:,2) == 4);
           if length(k) == 1
                dL_4P = durbin_watson_table(k, 3);
                dU_4P = durbin_watson_table(k, 4);
           elseif length(k) > 1
              dL_4P = durbin_watson_table(k(length(k)-1), 3) + (durbin_watson_table(k(length(k)), 3) ...
                  - durbin_watson_table(k(length(k)-1), 3))/10 * (N - durbin_watson_table(k(length(k)-1), 1));
              dU_4P = durbin_watson_table(k(length(k)-1), 4) + (durbin_watson_table(k(length(k)), 4) ...
                  - durbin_watson_table(k(length(k)-1), 4))/10 * (N - durbin_watson_table(k(length(k)-1), 1));
           end
        else % greater than 2000 undefined
           dL_4P = NaN;
           dU_4P = NaN;
        end 
       
        
         if length(dL_2P) < 1, dL_2P = 9999, end;
         if length(dU_2P) < 1, dU_2P = 9999, end;
         if length(dL_3P) < 1, dL_3P = 9999, end;
         if length(dU_3P) < 1, dU_3P = 9999, end; 
         if length(dL_4P) < 1, dL_4P = 9999, end;
         if length(dU_4P) < 1, dU_4P = 9999, end; 
         
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
              
    % Durbin-Watson linear fit
        res_lag = zeros (N,1);
        res_lag(1) = NaN;
        res_lag(2:N) = resid_lin(1:N-1);
        diffsqr = (resid_lin - res_lag).^2;
        d_lin = sum(diffsqr(2:length(diffsqr),1))/(sum(resid_lin.^2));
        % Durbin-Watson Polynom 2nd order
        res_lag(2:N) = resid_pol2(1:N-1);
        diffsqr = (resid_pol2 - res_lag).^2;
        d_pol2 = sum(diffsqr(2:length(diffsqr),1))/(sum(resid_pol2.^2));
        % Durbin-Watson Polynom 3rd order
        res_lag(2:N) = resid_pol3(1:N-1);
        diffsqr = (resid_pol3 - res_lag).^2;
        d_pol3 = sum(diffsqr(2:length(diffsqr),1))/(sum(resid_pol3.^2));
        % Durbin-Watson exponential fit
        try
        res_lag(2:N) = resid_exp(1:N-1);
        diffsqr = (resid_exp - res_lag).^2;
        d_exp = sum(diffsqr(2:length(diffsqr),1))/(sum(resid_exp.^2));
       catch
           d_exp=-9999
       end
        
        % Durbin-Watson 17th order power series expansion of exponential function
        res_lag(2:N) = resid_powser17(1:N-1);
        diffsqr = (resid_powser17 - res_lag).^2;
        d_powser17 = sum(diffsqr(2:length(diffsqr),1))/(sum(resid_powser17.^2)); 
        d_living = -9999;
            
    % Kolmogorov-Smirnov test for normality of the residuals; P('K.S.) should be above 0.05
    %linear
    resid_lin_norm = (resid_lin - mean(resid_lin))/std(resid_lin);
    [HKS_lin, PKS_lin] = kstest(resid_lin_norm);
    % polynomial 2nd order
    resid_pol2_norm = (resid_pol2 - mean(resid_pol2))/std(resid_pol2);
    [HKS_pol2, PKS_pol2] = kstest(resid_pol2_norm);
    % polynomial 3rd order
    resid_pol3_norm = (resid_pol3 - mean(resid_pol3))/std(resid_pol3);
    [HKS_pol3, PKS_pol3] = kstest(resid_pol3_norm);
    % exponential
    try
    resid_exp_norm = (resid_exp - mean(resid_exp))/std(resid_exp);
    [HKS_exp, PKS_exp] = kstest(resid_exp_norm);
    catch
    lasterr= lasterror
    lasterr.message
    HKS_exp=-9999;
    PKS_exp=-9999;
    end
    % power series expansion of exponential function 17th order
    resid_powser17_norm = (resid_powser17 - mean(resid_powser17))/std(resid_powser17);
    [HKS_powser17, PKS_powser17] = kstest(resid_powser17_norm);
    % Livingston function
    try
    resid_living_norm = (resid_living - mean(resid_living))/std(resid_living);
    [HKS_living, PKS_living] = kstest(resid_living_norm);
    catch 
    lasterr= lasterror
    lasterr.message
    HKS_living=-9999;
    PKS_living=-9999;
    end
       
        
    %D'Agostino-Pearson's K2 test for assessing normality of data using
    %skewness and kurtosis. P('Ag.) should be above 0.05
    significance_DagosPtest = 0.05;  
    % linear     
    resid_lin_sort = sort(resid_lin);
    [K2_dAgos_lin, P_dAgos_lin] = DagosPtest(resid_lin_sort, significance_DagosPtest);
    % Polynom 2nd order     
    resid_pol2_sort = sort(resid_pol2);
    [K2_dAgos_pol2, P_dAgos_pol2] = DagosPtest(resid_pol2_sort, significance_DagosPtest);
    % Polynom 3rd order    
    resid_pol3_sort = sort(resid_pol3);
    [K2_dAgos_pol3, P_dAgos_pol3] = DagosPtest(resid_pol3_sort, significance_DagosPtest);
    % exponential 
    try
    resid_exp_sort = sort(resid_exp);
    [K2_dAgos_exp, P_dAgos_exp] = DagosPtest(resid_exp_sort, significance_DagosPtest);
    catch
        lasterr= lasterror
    lasterr.message
    K2_dAgos_exp=-9999;
    P_dAgos_exp=-9999;
    end
    % 17th order power series expansion of exponential function      
    resid_powser17_sort = sort(resid_powser17);
    [K2_dAgos_powser17, P_dAgos_powser17] = DagosPtest(resid_powser17_sort, significance_DagosPtest);
    % Livingston function
    try
    resid_living_sort = sort(resid_living);
    [K2_dAgos_living, P_dAgos_living] = DagosPtest(resid_living_sort, significance_DagosPtest);
    catch 
    lasterr= lasterror
    lasterr.message
    K2_dAgos_living=-9999;
    P_dAgos_living=-9999;
    end
    
%----------------------------------------------------------------------------------------
% Conversion of serial date number to vector of components, preparation
    % of datafilename strings
    
    datetime1 = datevec(headerdata(i,1)/86400);
    datetime2 = datevec(headerdata(i,2)/86400);
    
    if datetime1(2)<10
        month = ['0', num2str(datetime1(2))];
    else
        month = num2str(datetime1(2));
    end
    if datetime1(3)<10
        day = ['0', num2str(datetime1(3))];
    else
        day = num2str(datetime1(3));
    end
    if datetime1(4)<10
        hour1 = ['0', num2str(datetime1(4))];
    else
        hour1 = num2str(datetime1(4));
    end
    if datetime1(5)<10
        minute1 = ['0', num2str(datetime1(5))];
    else
        minute1 = num2str(datetime1(5));
    end
    if round(datetime1(6))<10
        second1 = ['0', num2str(round(datetime1(6)))];
    elseif round(datetime1(6)) >= 10 & round(datetime1(6)) < 60
        second1 = num2str(round(datetime1(6)));
    else
        second1 = ['00']
        if datetime1(5)<10
        minute1 = ['0', num2str(datetime1(5)+1)];
        else
        minute1 = num2str(datetime1(5)+1);
        end
    end
    if datetime2(4)<10
        hour2 = ['0', num2str(datetime2(4))];
    else
        hour2 = num2str(datetime2(4));
    end
    if datetime2(4)<10
        hour2 = ['0', num2str(datetime2(4))];
    else
        hour2 = num2str(datetime2(4));
    end
    if datetime2(5)<10
        minute2 = ['0', num2str(datetime2(5))];
    else
        minute2 = num2str(datetime2(5));
    end
    if round(datetime2(6))<10
        second2 = ['0', num2str(round(datetime2(6)))];
    elseif round(datetime2(6)) >= 10 & round(datetime2(6)) < 60
        second2 = num2str(round(datetime2(6)));
    else
        second2 = ['00']
        if datetime2(5)<10
        minute2 = ['0', num2str(datetime2(5)+1)];
        else
        minute2 = num2str(datetime2(5)+1);
        end
    end
       
    csvfilename = resultsfilename;
    resultspath = 'D:\Ph.D\Daten\Matlab\Skript_Example\results';
    
%------------------------------------------------------------------------------------          
              
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % graphical display of results
    clf; % clear figure1
    
   
    set(gcf,'CloseRequestFcn','Stop_Callback')  % stop
      
    % Plot of residuals (exp (cyan)and linear(blue)) versus xi
    handle = subplot(4,2,7); 
    [AX H1 H2]= plotyy(x, resid_exp, x, resid_lin); hold on;
    colour_green = [150 200 54] ./ 255;
    colour_orange = [250 137 78] ./ 255;
    colour_brown = [150 80 20] ./ 255;
    colour_lightgreen = [50 200 70] ./ 255;
    colour_lightblue = [9 227 255] ./ 255;
    set(H1,'LineStyle', '-', 'marker','+','Color',colour_brown, 'LineWidth', 1.0); % exponential in light blue (solid)
    set(H2,'LineStyle', '--','marker','+','Color',colour_lightgreen, 'LineWidth', 1.0); % linear in dark blue (dashed)
    set(AX(1), 'xlim',([min(plotmatrix1(:, timecol))-0.02 * max(plotmatrix1(:, timecol)), max(plotmatrix1(:, timecol))+ 0.02 * max(plotmatrix1(:, timecol))]));
    set(AX(1), 'ylim',([min(resid_exp) - 0.02 * abs(mean(resid_exp)), max(resid_exp) + 0.02 * abs(mean(resid_exp))]));
    set(AX(2), 'xlim',([min(plotmatrix1(:, timecol))-0.02 * max(plotmatrix1(:, timecol)), max(plotmatrix1(:, timecol))+ 0.02 * max(plotmatrix1(:, timecol))]));
    set(AX(2), 'ylim',([min(resid_lin) - 0.02 * abs(mean(resid_lin)), max(resid_lin) + 0.02 * abs(mean(resid_lin))]));

    plot( x, noise, 'r:', x, -noise, 'r:', 'Linewidth', 2); 
    fontname = get(handle, 'FontName');
    set(gca,'position',[0.06, 0.055, 0.54, 0.16], 'FontSize', 10);
    handle = annotation ('Line', [0.06, 0.06], [0.28, 0.44]);
    xlabel( '\bftime (s)' );  ylabel(AX(1),'\bfresidual-exp (ppm)', 'FontSize', 10, 'Color', colour_brown); ylabel(AX(2), '\bfresidual-lin (ppm)', 'FontSize', 10, 'Color', colour_lightgreen);
    set(AX(1),'ycolor','k', 'FontSize', 10); set(AX(2),'ycolor','k', 'FontSize', 10);
    grid on; hold off;
      
    % plot of PAR and Tin
    handle = axes('Position', [0.0600, 0.275, 0.54, 0.16],...
           'XAxisLocation','bottom',...
           'YAxisLocation','left',...
           'XColor','k','YColor','k',...
           'Color', 'white',...
           'FontSize',10, 'LineWidth', 0.5); grid on; hold on;
    set(gca,'position',[0.0600, 0.275, 0.54, 0.16], 'FontSize', 10);
    plot(plotmatrix1(:,timecol), plotmatrix1(:,parcol), '-x', 'Linewidth', 1.8, 'Color', colour_green, 'Markersize', 3)
    axis([min(plotmatrix1(:, timecol))-0.02 * max(plotmatrix1(:, timecol)), max(plotmatrix1(:, timecol))+ 0.02 * max(plotmatrix1(:, timecol)), ...
        min(plotmatrix1(:,parcol)) - 0.02 * abs(mean(plotmatrix1(:,parcol))), max(plotmatrix1(:,parcol)) + 0.02 * abs(mean(plotmatrix1(:,parcol)))]);
    title([]);
    handle = xlabel('\bftime (s)'); 
    set(handle, 'Fontsize', 10);
    handle = ylabel('\bfPAR');
    set(handle, 'Fontsize', 10, 'Color', colour_green); hold off 
    
    handle = axes('Position', [0.0600, 0.275, 0.54, 0.16],...
           'XAxisLocation','top',...
           'YAxisLocation','right',...
           'XColor','k','YColor','k',...
           'XTickLabel', [],...
           'Color', 'none',...
           'FontSize',10, 'LineWidth', 0.5); grid on; hold on;
              
    plot(plotmatrix1(:,timecol), plotmatrix1(:,tincol), '+-', 'Linewidth', 1.7, 'Color', colour_orange, 'Markersize', 0.5);
    axis([min(plotmatrix1(:, timecol))-0.02 * max(plotmatrix1(:, timecol)), max(plotmatrix1(:, timecol))+ 0.02 * max(plotmatrix1(:, timecol)), ...
        min(plotmatrix1(:,tincol)) - 0.02 * abs(mean(plotmatrix1(:,tincol))), max(plotmatrix1(:,tincol)) + 0.02 * abs(mean(plotmatrix1(:,tincol)))]);
    set(gca,'position',[0.0600, 0.275, 0.54, 0.16], 'FontSize', 10);
    ylabel ('\bfT_C_h_a_m_b_e_r', 'Color', colour_orange);
        
    % result textbox1: parameters with errors, coefficients of determination R2 and R2adj, 
    % information criteria Akaike and Baye(Schwartz)
    if headerdata(i, lidacol) == 0;
        lida='light';
    else
        lida='dark';
    end   
    handle = annotation('textbox',[0.645, 0.475, 0.345, 0.5]);
    set(handle, 'BackgroundColor', [1,1,1], 'FontSize', 10)
    set(handle, 'String', ['\bfNo.: ', num2str(i), '\fontsize{6}\color{white}g\color{black}\fontsize{10} ', day, '.', month, '.', num2str(datetime1(1)), '    ', hour1, ':', minute1, ':', second1, ' \ldots ', hour2, ':', minute2, ':', second2, '\fontsize{6}\color{white}g\color{black}\fontsize{10} ID: ', num2str(headerdata(i,idcol)), '\fontsize{6}\color{white}g\color{black}\fontsize{10} n = ', num2str(N), '\fontsize{6}\color{white}g\color{black}\fontsize{10} ', lida, '\fontsize{6}\color{white}g\color{black}\fontsize{10} td: ', num2str(headerdata(i,thawcol)),'\fontsize{6}\color{white}g\color{black}\fontsize{10} Nr: ', num2str(headerdata(i,sampcol)),'\fontsize{6}\color{white}g\color{black}\fontsize{10} ', gas])
    handle = annotation('textbox',[0.645, 0.475, 0.0575, 0.462]);
    set(handle, 'String', {'\fontsize{8}variable'; 'P1'; 'se'; 'P2'; 'se'; 'P3'; 'se'; 'P4'; 'se'; '\fontsize{1}\color{white}g\color{black}\fontsize{8}'; 'sd_r_e_s'; 'rmse'; 'R2'; 'R2_a_d_j';  'AICc'; 'BIC'; '\fontsize{1}\color{white}g\color{black}\fontsize{8}'; 'f(t=0)'; 'se'; 'rel.err.'; 'f`(t=0)'; 'se'; '\fontsize{1}\color{white}g\color{black}\fontsize{8}'; 'flux'; 'se'; 'rel.err.'; 'dev.fact.'; 'p(F)'});
    handle = annotation('textbox',[0.0575 + 0.645, 0.475, 0.0575, 0.462]);
    set(handle, 'String', {'\fontsize{8}linear'; round2n(fitcoeff_lin(1),-6);  round2n(se_lin(1),-6); round2n(fitcoeff_lin(2),-6);  round2n(se_lin(2),-6); ' - '; ' - '; ' - '; ' - '; '\fontsize{1}\color{white}g\color{black}\fontsize{8}'; round2n(resStdev_lin,-6); round2n(rmse_lin,-6);  round2n(rsq_lin,-4); round2n(rsq_lin_adj,-4); round2n(AICc_lin, -2); round2n(BIC_lin, -2); '\fontsize{1}\color{white}g\color{black}\fontsize{8}'; round2n(fitcoeff_lin(1),-6);  round2n(se_lin(1),-6); round2n(relerr_lin(1),-6); round2n(fitcoeff_lin(2),-6);  round2n(se_lin(2),-6); '\fontsize{1}\color{white}g\color{black}\fontsize{8}'; round2n(flux_lin, -6); round2n(flux_lin_abserr, -6); round2n(flux_lin_relerr,-3); 1; P_Var_kleiner_lin});
    handle = annotation('textbox',[2*0.0575 + 0.645, 0.475, 0.0575, 0.462]);
    set(handle, 'String', {'\fontsize{8}poly. 2nd'; round2n(fitcoeff_pol2(1),-6); round2n(se_pol2(1),-6); round2n(fitcoeff_pol2(2),-6); round2n(se_pol2(2),-6); round2n(fitcoeff_pol2(3),-6); round2n(se_pol2(3),-6); ' - '; ' - '; '\fontsize{1}\color{white}g\color{black}\fontsize{8}'; round2n(resStdev_pol2,-6); round2n(rmse_pol2,-6); round2n(rsq_pol2,-4); round2n(rsq_pol2_adj,-4); round2n(AICc_pol2,-2); round2n(BIC_pol2,-2); '\fontsize{1}\color{white}g\color{black}\fontsize{8}'; round2n(fitcoeff_pol2(1),-6);  round2n(se_pol2(1),-6); round2n(relerr_pol2(1),-6); round2n(fitcoeff_pol2(2),-6);  round2n(se_pol2(2),-6); '\fontsize{1}\color{white}g\color{black}\fontsize{8}'; round2n(flux_pol2, -6); round2n(flux_pol2_abserr, -6); round2n(flux_pol2_relerr,-3); devfac_pol2; round2n(P_Var_kleiner_pol2,-5) });
    handle = annotation('textbox',[3*0.0575 + 0.645, 0.475, 0.0575, 0.462]);
    set(handle, 'String', {'\fontsize{8}poly. 3rd'; round2n(fitcoeff_pol3(1),-6); round2n(se_pol3(1),-6); round2n(fitcoeff_pol3(2),-6); round2n(se_pol3(2),-6); round2n(fitcoeff_pol3(3),-6); round2n(se_pol3(3),-6); round2n(fitcoeff_pol3(4),-7); round2n(se_pol3(4),-7); '\fontsize{1}\color{white}g\color{black}\fontsize{8}'; round2n(resStdev_pol3,-6); round2n(rmse_pol3,-6); round2n(rsq_pol3,-4); round2n(rsq_pol3_adj,-4); round2n(AICc_pol3,-2); round2n(BIC_pol3,-2); '\fontsize{1}\color{white}g\color{black}\fontsize{8}'; round2n(fitcoeff_pol3(1),-6);  round2n(se_pol3(1),-6); round2n(relerr_pol3(1),-6); round2n(fitcoeff_pol3(2),-6);  round2n(se_pol3(2),-6); '\fontsize{1}\color{white}g\color{black}\fontsize{8}'; round2n(flux_pol3, -6); round2n(flux_pol3_abserr, -6); round2n(flux_pol3_relerr,-3); devfac_pol3; round2n(P_Var_kleiner_pol3,-5) });
    handle = annotation('textbox',[4*0.0575 + 0.645, 0.475, 0.0575, 0.462]);
    set(handle, 'String', {'\fontsize{8}expon.'; round2n(fitcoeff_exp(1),-6); round2n(se_exp(1),-6); round2n(fitcoeff_exp(2),-6); round2n(se_exp(2),-6); round2n(fitcoeff_exp(3),-6); round2n(se_exp(3),-6); ' - '; ' - '; '\fontsize{1}\color{white}g\color{black}\fontsize{8}'; round2n(resStdev_exp,-6); round2n(rmse_exp,-6); round2n(rsq_exp,-4); round2n(rsq_exp_adj,-4); round2n(AICc_exp,-2); round2n(BIC_exp,-2); '\fontsize{1}\color{white}g\color{black}\fontsize{8}'; round2n(offset_exp,-6);  round2n(abserr_offset_exp,-6); round2n(relerr_offset_exp,-6); round2n(slope_exp,-6);  round2n(abserr_slope_exp,-6);  '\fontsize{1}\color{white}g\color{black}\fontsize{8}'; round2n(flux_exp, -6); round2n(flux_exp_abserr, -6); round2n(flux_exp_relerr,-3); devfac_exp; round2n(P_Var_kleiner_exp,-5) });
    handle = annotation('textbox',[5*0.0575 + 0.645, 0.475, 0.0575, 0.462]);
    set(handle, 'String', {'\fontsize{8}p.s.e.17th'; round2n(fitcoeff_powser17(1),-6); round2n(se_powser17(1),-6); round2n(fitcoeff_powser17(2),-6); round2n(se_powser17(2),-6); round2n(fitcoeff_powser17(3),-6); round2n(se_powser17(3),-6); ' - '; ' - '; '\fontsize{1}\color{white}g\color{black}\fontsize{8}'; round2n(resStdev_powser17,-6); round2n(rmse_powser17,-6); round2n(rsq_powser17,-4); round2n(rsq_powser17_adj,-4); round2n(AICc_powser17,-2); round2n(BIC_powser17,-2); '\fontsize{1}\color{white}g\color{black}\fontsize{8}'; round2n(fitcoeff_powser17(1),-6);  round2n(se_powser17(1),-6); round2n(relerr_powser17(1),-6); round2n(fitcoeff_powser17(2),-6);  round2n(se_powser17(2),-6); '\fontsize{1}\color{white}g\color{black}\fontsize{8}'; round2n(flux_powser17, -6); round2n(flux_powser17_abserr, -6); round2n(flux_powser17_relerr,-3); devfac_powser17; round2n(P_Var_kleiner_powser17,-5) });
    handle = annotation('textbox',[0.645, 0.475, 0.345, 0.443]);
    set(handle, 'FaceAlpha', 0);
    handle = annotation('Line',[0.645, 0.645+0.345], [0.475+0.462, 0.475+0.462]);
    set(handle, 'LineWidth', 1.5);
    
           
    % results textbox 2: slow environmental data, treatment IDs, etc.
    handle = annotation('rectangle',[0.645, 0.275, 0.345 0.16]);
    set(handle, 'FaceAlpha', 1, 'FaceColor', [1, 1, 1])
    handle = annotation('textbox',[0.645, 0.275, 0.345, 0.16]);
    set(handle, 'String', ['\fontsize{6}\color{white}g\color{black}\fontsize{10} ', '\bf', gas, '\fontsize{6}\color{white}g\color{black}\fontsize{10} ', 'flux (lin): ', '\fontsize{6}\color{white}g\color{black}\fontsize{10}', num2str(flux_lin), '\fontsize{6}\color{white}g\color{black}\fontsize{10} ', ' +/-', '\fontsize{6}\color{white}g\color{black}\fontsize{10}', num2str(flux_lin_abserr), '\fontsize{6}\color{white}g\color{black}\fontsize{10} ', 'g s^{-1} m^{-2}'])
    handle = annotation('textbox',[0.645, 0.275, 0.345, 0.08]);
    set(handle, 'String', {['\fontsize{6}\color{white}g\color{black}\fontsize{9} ', 'PAR_{inside}:', '\fontsize{6}\color{white}g\color{black}\fontsize{9}(', num2str(mean_PAR_all), '\fontsize{6}\color{white}g\color{black}\fontsize{9} ', ' +/- ', '\fontsize{6}\color{white}g\color{black}\fontsize{9} ', num2str(std_PAR_all), ')', '\fontsize{6}\color{white}g\color{black}\fontsize{9} ', 'mol s^{-1} m^{-2}']; ['\fontsize{6}\color{white}g\color{black}\fontsize{9} ', 'PAR_{outside}:', '\fontsize{6}\color{white}g\color{black}\fontsize{9}(', num2str(metdata_selected(1,metPARincol)), ')', '\fontsize{6}\color{white}g\color{black}\fontsize{9} ', 'mol s^{-1} m^{-2}' ] });
    handle = annotation('textbox',[0.645, 0.275, 0.345, 0.13]);
    set(handle, 'String', ['\fontsize{6}\color{white}g\color{black}\fontsize{10} ', '\bf', gas, '\fontsize{6}\color{white}g\color{black}\fontsize{10} ', 'flux (exp): ', '\fontsize{6}\color{white}g\color{black}\fontsize{10}', num2str(flux_exp), '\fontsize{6}\color{white}g\color{black}\fontsize{10} ', ' +/-', '\fontsize{6}\color{white}g\color{black}\fontsize{10}', num2str(flux_exp_abserr), '\fontsize{6}\color{white}g\color{black}\fontsize{10} ', 'g s^{-1} m^{-2}'])
          
    % results textbox 3: analysis of residuals: Durbin-Watson test, Kolomogoroff-Smirnoff-Test;
    % D'Agostini-pearsson-test, chi2test for goodness of fit
    handle = annotation('rectangle',[0.645, 0.055, 0.345 0.16]);
    set(handle, 'FaceAlpha', 1, 'FaceColor', [1, 1, 1])
    handle = annotation('textbox',[0.645, 0.055, 0.0575, 0.16]);
    set(handle, 'String', {'\fontsize{8}test var.'; 'dL(table)'; 'dU(table)'; 'd(data)'; 'P(K.S.)'; 'P(dAg.)'; 'P(\chi)'});
    handle = annotation('textbox',[0.0575 + 0.645, 0.055, 0.0575, 0.16]);
    set(handle, 'String', {'\fontsize{8}linear'; round2n(dL_2P,-2); round2n(dU_2P,-2); round2n(d_lin,-2); round2n(PKS_lin,-3); round2n(P_dAgos_lin,-3); round2n(chi2_p_lin, -3)});
    handle = annotation('textbox',[2*0.0575 + 0.645, 0.055, 0.0575, 0.16]);
    set(handle, 'String', {'\fontsize{8}poly. 2nd'; round2n(dL_3P,-2); round2n(dU_3P,-2); round2n(d_pol2,-2); round2n(PKS_pol2,-3); round2n(P_dAgos_pol2,-3); round2n(chi2_p_pol2, -3) });
    handle = annotation('textbox',[3*0.0575 + 0.645, 0.055, 0.0575, 0.16]);
    set(handle, 'String', {'\fontsize{8}poly. 3rd'; round2n(dL_4P,-2); round2n(dU_4P,-2); round2n(d_pol3,-2); round2n(PKS_pol3,-3); round2n(P_dAgos_pol3,-3); round2n(chi2_p_pol3, -3)});
    handle = annotation('textbox',[4*0.0575 + 0.645, 0.055, 0.0575, 0.16]);
    set(handle, 'String', {'\fontsize{8}expon.'; round2n(dL_3P,-2); round2n(dU_3P,-2); round2n(d_exp,-2); round2n(PKS_exp,-3); round2n(P_dAgos_exp,-3); round2n(chi2_p_exp, -3)});
    handle = annotation('textbox',[5*0.0575 + 0.645, 0.055, 0.0575, 0.16]);
    set(handle, 'String', {'\fontsize{8}p.s.e.17th'; round2n(dL_3P,-2); round2n(dU_3P,-2); round2n(d_powser17,-2); round2n(PKS_powser17,-3); round2n(P_dAgos_powser17, -3); round2n(chi2_p_powser17, -3)});
    handle = annotation('textbox',[0.645, 0.055, 0.345, 0.142]);
    set(handle, 'FaceAlpha', 0);
        
    % Plot data and regression lines: linear, exponential (y=a+b*exp(c*x)),
    % power series expansion 7th and 2nd order
    set(gcf,'Position',[3, 28, scrsz(3)-2*3, scrsz(4)-95]);
    
    h_ax_h2o = axes('Position', [0.060, 0.495, 0.540, 0.48],...
           'XAxisLocation','top',...
           'YAxisLocation','right',...
           'XTickLabel', [],...
           'XColor','k','YColor','k',...
           'FontSize',10, 'LineWidth', 0.5); grid on; hold on; 
    axis([min(plotmatrix1(:, timecol))-0.02 * max(plotmatrix1(:, timecol)), max(plotmatrix1(:, timecol))+ 0.02 * max(plotmatrix1(:, timecol)), ...
        min(plotmatrix1(:, h2ocol)) - 0.005 * abs(mean(plotmatrix1(:, h2ocol))), max(plotmatrix1(:, h2ocol)) + 0.005 * abs(mean(plotmatrix1(:, h2ocol)))]);
    line(plotmatrix1(:,timecol), plotmatrix1(:,h2ocol), 'Color', 'b', 'LineStyle', '--', 'Parent',h_ax_h2o);
    ylabel('\bfConcentration H_2O (ppm)'); hold on;
        
    h_ax_gas = axes('Position', [0.060, 0.495, 0.540, 0.48],...
           'XAxisLocation','bottom',...
           'YAxisLocation','left',...
           'XColor','k','YColor','k',...
           'Color', 'none',...
           'FontSize',10, 'LineWidth', 0.5); grid on; hold on; 
    axis([min(plotmatrix1(:, timecol))-0.02 * max(plotmatrix1(:, timecol)), max(plotmatrix1(:, timecol))+ 0.02 * max(plotmatrix1(:, timecol)), ...
        min([min(plotmatrix1(:, gascol)), min(y)]) - 0.005 * abs(mean(plotmatrix1(:, gascol))), max([max(plotmatrix1(:, gascol)), max(y)]) + 0.005 * abs(mean(plotmatrix1(:, gascol)))]);
    plot(plotmatrix1(:,timecol), plotmatrix1(:,gascol), 'Color', [0.6,0.83,0.62], 'LineStyle', 'none', 'Marker', '+', 'Parent', h_ax_gas); 
    plot( x , y , 'Linestyle', 'none', 'Marker', '+', 'Color', 'r'); hold on;
        
    plot( (0:1:max(x)) , fitcoeff_lin(1)+fitcoeff_lin(2)*(0:1:max(x)), 'k-',...
        (0:1:max(x)), fitcoeff_pol2(1) + fitcoeff_pol2(2)* (0:1:max(x)) + fitcoeff_pol2(3)*(0:1:max(x)).^2, 'r-',...
        (0:1:max(x)), fitcoeff_pol3(1) + fitcoeff_pol3(2)* (0:1:max(x)) + fitcoeff_pol3(3)*(0:1:max(x)).^2 + fitcoeff_pol3(4)*(0:1:max(x)).^3, 'r--',...
        (0:1:max(x)) , powerseriesexpansion17(fitcoeff_powser17, (0:1:max(x)) ), 'c--',...
        (0:1:max(x)), polyval(p_before1,(0:1:max(x)),S_before1), 'm--', 'Linewidth', 1); hold on;
    scatter(0,0,'Marker', 'none')
    if  error_occured_exp == 0
        plot((0:1:max(x)) , exponential(fitcoeff_exp, (0:1:max(x))), 'b-' )
    end
    if error_occured_living == 0  
    plot((0:1:max(x)), living(fitcoeff_living, (0:1:max(x))), 'g--')
    end
    if error_occured_combined == 0
    plot(xtest, y_powser_combined, 'g-')   
    plot(wendepunkt,powerseriesexpansion17_combined(fitcoeff_powser17_comb, wendepunkt), 'X', 'MarkerSize', 20, 'LineWidth', 3, 'MarkerEdgeColor', 'g') 
    end
    
        linkaxes([h_ax_h2o, h_ax_gas],'x')
        plot(0, 0, 'Linestyle', '--', 'Color', 'b')
        h2o_legend = 'H_2O concentration';
    
    if str2num(watercorrection) == 1
        dataaround = 'data around, uncorr. for H_2O';
        gasverstime = 'gas concentration, corr. for H_2O';
    else
        dataaround = 'data around';
        gasverstime = 'gas concentration';
    end
    
    xlabel( '\bftime (s)' );  ylabel('\bfConcentration Gas (ppm)'); hold on;
    if error_occured_exp == 0
    if error_occured_living == 0 
    if error_occured_combined == 0
    h_legend = legend(h_ax_gas, dataaround, gasverstime, 'linear', 'polynomial 2nd order', 'polynomial 3rd order',...
        'power series 17th', ['best poly.: order ', num2str(order_before1), ' ; BIC: ', num2str(round2n(BIC_before1,-2))], ['(badly cond. from order ', num2str(min(order_bad_condition)), ')'], 'exponential', 'living', 'combined-S', 'inflection', h2o_legend); 
    else
    h_legend = legend(h_ax_gas, dataaround, gasverstime, 'linear', 'polynomial 2nd order', 'polynomial 3rd order',...
        'power series 17th', ['best poly.: order ', num2str(order_before1), ' ; BIC: ', num2str(round2n(BIC_before1,-2))], ['(badly cond. from order ', num2str(min(order_bad_condition)), ')'], 'exponential', 'living', h2o_legend);  
    end
    else
    if error_occured_combined == 0
    h_legend = legend(h_ax_gas, dataaround, gasverstime, 'linear', 'polynomial 2nd order', 'polynomial 3rd order',...
        'power series 17th', ['best poly.: order ', num2str(order_before1), ' ; BIC: ', num2str(round2n(BIC_before1,-2))], ['(badly cond. from order ', num2str(min(order_bad_condition)), ')'], 'exponential', 'combined-S', 'inflection', h2o_legend); 
    else
    h_legend = legend(h_ax_gas, dataaround, gasverstime, 'linear', 'polynomial 2nd order', 'polynomial 3rd order',...
        'power series 17th', ['best poly.: order ', num2str(order_before1), ' ; BIC: ', num2str(round2n(BIC_before1,-2))], ['(badly cond. from order ', num2str(min(order_bad_condition)), ')'], 'exponential', h2o_legend);  
    end
    end
    else
    if error_occured_living == 0 
    if error_occured_combined == 0
    h_legend = legend(h_ax_gas, dataaround, gasverstime, 'linear', 'polynomial 2nd order', 'polynomial 3rd order',...
        'power series 17th', ['best poly.: order ', num2str(order_before1), ' ; BIC: ', num2str(round2n(BIC_before1,-2))], ['(badly cond. from order ', num2str(min(order_bad_condition)), ')'], 'living', 'combined-S', 'inflection', h2o_legend); 
    else
    h_legend = legend(h_ax_gas, dataaround, gasverstime, 'linear', 'polynomial 2nd order', 'polynomial 3rd order',...
        'power series 17th', ['best poly.: order ', num2str(order_before1), ' ; BIC: ', num2str(round2n(BIC_before1,-2))], ['(badly cond. from order ', num2str(min(order_bad_condition)), ')'], 'living', h2o_legend);  
    end
    else
    if error_occured_combined == 0
    h_legend = legend(h_ax_gas, dataaround, gasverstime, 'linear', 'polynomial 2nd order', 'polynomial 3rd order',...
        'power series 17th', ['best poly.: order ', num2str(order_before1), ' ; BIC: ', num2str(round2n(BIC_before1,-2))], ['(badly cond. from order ', num2str(min(order_bad_condition)), ')'], 'combined-S', 'inflection', h2o_legend); 
    else
    h_legend = legend(h_ax_gas, dataaround, gasverstime, 'linear', 'polynomial 2nd order', 'polynomial 3rd order',...
        'power series 17th', ['best poly.: order ', num2str(order_before1), ' ; BIC: ', num2str(round2n(BIC_before1,-2))], ['(badly cond. from order ', num2str(min(order_bad_condition)), ')'], h2o_legend);  
    end
    end 
    end
    %legend(h_legend, 'Location', 'Best');
    %handle = annotation ('Line', [0.060,0.060+0.540], [0.4935, 0.4935]);
    %set(handle, 'Linewidth', 0.5); hold off;
    
    if control == 'm'
    
    if i > 1 
    h_back = uicontrol('Style', 'pushbutton', 'String', '< Back ',...
    'Position', [650 5 45 20], 'Callback', 'Back_Callback');
    end
    if i < headerrows
    h_next = uicontrol('Style', 'pushbutton', 'String', '> Next ',...
    'Position', [700 5 45 20], 'Callback', 'Next_Callback');
    end
    h_manual_discard = uicontrol('Style', 'pushbutton', 'String', ' Discardint. ',...
    'Position', [750 5 75 20], 'Callback', 'Discard_Callback');
    h_manual_stop = uicontrol('Style', 'pushbutton', 'String', ' Quit ',...
    'Position', [830 5 45 20], 'Callback', 'Stop_Callback');
    
    uiwait
    if IMIN == 0;
        manual_discard_start = -99.9;
        manual_discard_end = -99.9;
      
                       output = [i, headerdata(i,1)/86400-693960, str2num(discardstart), str2num(interval), str2num(mode), noise_gas, str2num(watercorrection), conc_unit_factor,...
                min(calcmatrix_nan_removed(:,1))/86400-693960, max(calcmatrix_nan_removed(:,1))/86400-693960, min(calcmatrix1(:,1)), max(calcmatrix1(:,1)),...
                N, mean(y), std(y), min(y), max(y), fitcoeff_lin(1), se_lin(1), relerr_lin(1), fitcoeff_lin(2), se_lin(2), relerr_lin(2), t_lin, prob_lin,...
                rsq_lin, rsq_lin_adj, SSR_lin, resStdev_lin, rmse_lin, Qx, SSR_norm_lin, chi2_p_lin, BIC_lin, AICc_lin, flux_lin, flux_lin_abserr, flux_lin_y_without, flux_lin_abserr_y_without...
                fitcoeff_pol2(1), se_pol2(1), relerr_pol2(1), fitcoeff_pol2(2), se_pol2(2), relerr_pol2(2), fitcoeff_pol2(3), se_pol2(3), relerr_pol2(3), t_pol2, prob_pol2,...
                rsq_pol2, rsq_pol2_adj, SSR_pol2, resStdev_pol2, rmse_pol2, SSR_norm_pol2, chi2_p_pol2, BIC_pol2, AICc_pol2, flux_pol2, flux_pol2_abserr, devfac_pol2,...
                fitcoeff_pol3(1), se_pol3(1), relerr_pol3(1), fitcoeff_pol3(2), se_pol3(2), relerr_pol3(2), fitcoeff_pol3(3), se_pol3(3), relerr_pol3(3), ...
                fitcoeff_pol3(4), se_pol3(4), relerr_pol3(4), t_pol3, prob_pol3, rsq_pol3, rsq_pol3_adj, SSR_pol3, resStdev_pol3, rmse_pol3, SSR_norm_pol3, chi2_p_pol3, BIC_pol3, AICc_pol3, flux_pol3, flux_pol3_abserr, devfac_pol3, ...
                order_before1,...
                fitcoeff_exp(1), se_exp(1), relerr_exp(1), fitcoeff_exp(2), se_exp(2), relerr_exp(2), fitcoeff_exp(3), se_exp(3), relerr_exp(3), t_exp, prob_exp,...
                rsq_exp, rsq_exp_adj, SSR_exp, resStdev_exp, rmse_exp, SSR_norm_exp, chi2_p_exp, BIC_exp, AICc_exp, ...
                offset_exp, abserr_offset_exp, relerr_offset_exp, slope_exp, abserr_slope_exp, relerr_slope_exp, flux_exp, flux_exp_abserr, devfac_exp,...
                fitcoeff_powser17(1), se_powser17(1), relerr_powser17(1), fitcoeff_powser17(2), se_powser17(2), relerr_powser17(2), fitcoeff_powser17(3), se_powser17(3), relerr_powser17(3), t_powser17, prob_powser17,...
                rsq_powser17, rsq_powser17_adj, SSR_powser17, resStdev_powser17, rmse_powser17, SSR_norm_powser17, chi2_p_powser17, BIC_powser17, AICc_powser17, flux_powser17, flux_powser17_abserr, devfac_powser17, error_powser17,...
                P_Var_kleiner_lin, P_Var_kleiner_pol2, P_Var_kleiner_pol3, P_Var_kleiner_exp, P_Var_kleiner_powser17, P_Var_kleiner_living, P_Var_kleiner_powser17alspol2, P_Var_kleiner_livingalspowser17, devfac_powser17zupol2, devfac_livingzupowser17,...
                d_lin, dL_2P, dU_2P, d_pol2, dL_3P, dU_3P, d_pol3, dL_4P, dU_4P, d_exp, dL_3P, dU_3P, d_powser17, dL_3P, dU_3P, d_living, dL_3P, dU_3P,...
                PKS_lin, PKS_pol2, PKS_pol3, PKS_exp, PKS_powser17, PKS_living,...
                P_dAgos_lin, P_dAgos_pol2, P_dAgos_pol3, P_dAgos_exp, P_dAgos_powser17, P_dAgos_living, o,...
                fitcoeff_powser17_comb(1), se_powser17_comb(1), relerr_powser17_comb(1), fitcoeff_powser17_comb(2), se_powser17_comb(2), relerr_powser17_comb(2),fitcoeff_powser17_comb(3), se_powser17_comb(3), relerr_powser17_comb(3), fitcoeff_combined(4), fitcoeff_combined(5), wendepunkt, wendepunktssteigung,...
                rsq_powser17_comb, rsq_powser17_comb_adj, SSR_powser17_comb, resStdev_powser17_comb, rmse_powser17_comb, SSR_norm_powser17_comb, chi2_p_powser17_comb, BIC_powser17_comb, AICc_powser17_comb,...
                fitcoeff_living(1), se_living(1), relerr_living(1), fitcoeff_living(2), se_living(2), relerr_living(2), fitcoeff_living(3), se_living(3), relerr_living(3), t_living, prob_living,...
                rsq_living, rsq_living_adj, SSR_living, resStdev_living, rmse_living, SSR_norm_living, chi2_p_living, BIC_living, AICc_living, flux_living, flux_living_abserr, devfac_living...
                mean_PAR_all, std_PAR_all, mean_PAR_10first, std_PAR_10first, mean_Tin_all, std_Tin_all, mean_Tin_10first, std_Tin_10first, mean_Tsoil_all, std_Tsoil_all, mean_Tsoil_10first, std_Tsoil_10first,...
                mean_VWC_all, std_VWC_all, mean_h2o_all, std_h2o_all, mean_h2o_10first, std_h2o_10first, e_sat_all, e_sat_10first, VPD_all, VPD_10first ,...
                headerdata(i,1)/86400-693960, headerdata(i,2)/86400-693960, headerdata(i,3:headercolumns)];
            
                    metdata_output = [i, metdata(j_met,1)/86400-693960, metdata(j_met,2:metdatacolumns)];
            o=1; 
    dlmwrite(csvfilename, output, '-append', 'precision', 15);
    metdatacsvfilename=['met_', csvfilename];
    dlmwrite(metdatacsvfilename, metdata_output, '-append', 'precision', 15) ;
    % Saving of diagram figure: Name: 'year_month_day_hour_minute_second_gas_vs_time.jpg'
    set(gcf, 'PaperPositionMode', 'auto')
    saveas(gcf,[num2str(datetime1(1)), month, day, '_', hour1, minute1, second1, '_', num2str(headerdata(i,idcol)),'_',gas, '_conc_vs_time', '.png']);
                   
    elseif IMIN == -2;
       
             output = [i, headerdata(i,1)/86400-693960, str2num(discardstart), str2num(interval), str2num(mode), noise_gas, str2num(watercorrection), conc_unit_factor,...
                min(calcmatrix_nan_removed(:,1))/86400-693960, max(calcmatrix_nan_removed(:,1))/86400-693960, min(calcmatrix1(:,1)), max(calcmatrix1(:,1)),...
                N, mean(y), std(y), min(y), max(y), fitcoeff_lin(1), se_lin(1), relerr_lin(1), fitcoeff_lin(2), se_lin(2), relerr_lin(2), t_lin, prob_lin,...
                rsq_lin, rsq_lin_adj, SSR_lin, resStdev_lin, rmse_lin, Qx, SSR_norm_lin, chi2_p_lin, BIC_lin, AICc_lin, flux_lin, flux_lin_abserr, flux_lin_y_without, flux_lin_abserr_y_without...
                fitcoeff_pol2(1), se_pol2(1), relerr_pol2(1), fitcoeff_pol2(2), se_pol2(2), relerr_pol2(2), fitcoeff_pol2(3), se_pol2(3), relerr_pol2(3), t_pol2, prob_pol2,...
                rsq_pol2, rsq_pol2_adj, SSR_pol2, resStdev_pol2, rmse_pol2, SSR_norm_pol2, chi2_p_pol2, BIC_pol2, AICc_pol2, flux_pol2, flux_pol2_abserr, devfac_pol2,...
                fitcoeff_pol3(1), se_pol3(1), relerr_pol3(1), fitcoeff_pol3(2), se_pol3(2), relerr_pol3(2), fitcoeff_pol3(3), se_pol3(3), relerr_pol3(3), ...
                fitcoeff_pol3(4), se_pol3(4), relerr_pol3(4), t_pol3, prob_pol3, rsq_pol3, rsq_pol3_adj, SSR_pol3, resStdev_pol3, rmse_pol3, SSR_norm_pol3, chi2_p_pol3, BIC_pol3, AICc_pol3, flux_pol3, flux_pol3_abserr, devfac_pol3, ...
                order_before1,...
                fitcoeff_exp(1), se_exp(1), relerr_exp(1), fitcoeff_exp(2), se_exp(2), relerr_exp(2), fitcoeff_exp(3), se_exp(3), relerr_exp(3), t_exp, prob_exp,...
                rsq_exp, rsq_exp_adj, SSR_exp, resStdev_exp, rmse_exp, SSR_norm_exp, chi2_p_exp, BIC_exp, AICc_exp, ...
                offset_exp, abserr_offset_exp, relerr_offset_exp, slope_exp, abserr_slope_exp, relerr_slope_exp, flux_exp, flux_exp_abserr, devfac_exp,...
                fitcoeff_powser17(1), se_powser17(1), relerr_powser17(1), fitcoeff_powser17(2), se_powser17(2), relerr_powser17(2), fitcoeff_powser17(3), se_powser17(3), relerr_powser17(3), t_powser17, prob_powser17,...
                rsq_powser17, rsq_powser17_adj, SSR_powser17, resStdev_powser17, rmse_powser17, SSR_norm_powser17, chi2_p_powser17, BIC_powser17, AICc_powser17, flux_powser17, flux_powser17_abserr, devfac_powser17, error_powser17,...
                P_Var_kleiner_lin, P_Var_kleiner_pol2, P_Var_kleiner_pol3, P_Var_kleiner_exp, P_Var_kleiner_powser17, P_Var_kleiner_living, P_Var_kleiner_powser17alspol2, P_Var_kleiner_livingalspowser17, devfac_powser17zupol2, devfac_livingzupowser17,...
                d_lin, dL_2P, dU_2P, d_pol2, dL_3P, dU_3P, d_pol3, dL_4P, dU_4P, d_exp, dL_3P, dU_3P, d_powser17, dL_3P, dU_3P, d_living, dL_3P, dU_3P,...
                PKS_lin, PKS_pol2, PKS_pol3, PKS_exp, PKS_powser17, PKS_living,...
                P_dAgos_lin, P_dAgos_pol2, P_dAgos_pol3, P_dAgos_exp, P_dAgos_powser17, P_dAgos_living, o,...
                fitcoeff_powser17_comb(1), se_powser17_comb(1), relerr_powser17_comb(1), fitcoeff_powser17_comb(2), se_powser17_comb(2), relerr_powser17_comb(2),fitcoeff_powser17_comb(3), se_powser17_comb(3), relerr_powser17_comb(3), fitcoeff_combined(4), fitcoeff_combined(5), wendepunkt, wendepunktssteigung,...
                rsq_powser17_comb, rsq_powser17_comb_adj, SSR_powser17_comb, resStdev_powser17_comb, rmse_powser17_comb, SSR_norm_powser17_comb, chi2_p_powser17_comb, BIC_powser17_comb, AICc_powser17_comb,...
                fitcoeff_living(1), se_living(1), relerr_living(1), fitcoeff_living(2), se_living(2), relerr_living(2), fitcoeff_living(3), se_living(3), relerr_living(3), t_living, prob_living,...
                rsq_living, rsq_living_adj, SSR_living, resStdev_living, rmse_living, SSR_norm_living, chi2_p_living, BIC_living, AICc_living, flux_living, flux_living_abserr, devfac_living...
                mean_PAR_all, std_PAR_all, mean_PAR_10first, std_PAR_10first, mean_Tin_all, std_Tin_all, mean_Tin_10first, std_Tin_10first, mean_Tsoil_all, std_Tsoil_all, mean_Tsoil_10first, std_Tsoil_10first,...
                mean_VWC_all, std_VWC_all, mean_h2o_all, std_h2o_all, mean_h2o_10first, std_h2o_10first, e_sat_all, e_sat_10first, VPD_all, VPD_10first ,...
                headerdata(i,1)/86400-693960, headerdata(i,2)/86400-693960, headerdata(i,3:headercolumns)];
                        
                    metdata_output = [i, metdata(j_met,1)/86400-693960, metdata(j_met,2:metdatacolumns)];
            o=1;
    dlmwrite(csvfilename, output, '-append', 'precision', 15) ;
    metdatacsvfilename=['met_', csvfilename];
    dlmwrite(metdatacsvfilename, metdata_output, '-append', 'precision', 15) ;
    % Saving of diagram figure: Name: 'year_month_day_hour_minute_second_gas_vs_time.jpg'
    set(gcf, 'PaperPositionMode', 'auto')% 'PaperSize', [1018, 673])
    saveas(gcf,[num2str(datetime1(1)), month, day, '_', hour1, minute1, second1, '_', num2str(headerdata(i,idcol)),'_',gas, '_conc_vs_time', '.png']);
            
    i=i-2;
    manual_discard_start = -99.9;
    manual_discard_end = -99.9;
        
    elseif IMIN == -10;
           
    h_low = imline(gca, [min(calcmatrix1(:,1)), min(calcmatrix1(:,1))], [min([min(plotmatrix1(:, gascol)), min(y)]) - 0.005 * abs(mean(plotmatrix1(:, gascol))), max([max(plotmatrix1(:, gascol)), max(y)]) + 0.005 * abs(mean(plotmatrix1(:, gascol)))])
    api1 = iptgetapi(h_low);
    imline1_id = api1.addNewPositionCallback(@(pos) title(mat2str(round(pos(1)))))
    api1 = iptgetapi(h_low);
    api1.setDragConstraintFcn(@(cand_pos)...
    cat(2,cand_pos(:,1),[min([min(plotmatrix1(:, gascol)), min(y)]) - 0.005 * abs(mean(plotmatrix1(:, gascol))); max([max(plotmatrix1(:, gascol)), max(y)]) + 0.005 * abs(mean(plotmatrix1(:, gascol)))]));
    h_high = imline(gca, [max(calcmatrix1(:,1)), max(calcmatrix1(:,1))], [min([min(plotmatrix1(:, gascol)), min(y)]) - 0.005 * abs(mean(plotmatrix1(:, gascol))), max([max(plotmatrix1(:, gascol)), max(y)]) + 0.005 * abs(mean(plotmatrix1(:, gascol)))])
    api2 = iptgetapi(h_high);
    imline2_id = api2.addNewPositionCallback(@(pos) title(mat2str(round(pos(1)))))
    api2 = iptgetapi(h_high);
    api2.setDragConstraintFcn(@(cand_pos)...
    cat(2,cand_pos(:,1),[min([min(plotmatrix1(:, gascol)), min(y)]) - 0.005 * abs(mean(plotmatrix1(:, gascol))); max([max(plotmatrix1(:, gascol)), max(y)]) + 0.005 * abs(mean(plotmatrix1(:, gascol)))]));
    
    if i > 1 
        delete(h_back);
    end
    if i < headercolumns
        delete(h_next);
    end
    delete(h_manual_stop);
    
    h_manual_stop = uicontrol('Style', 'pushbutton', 'String', ' Quit ',...
    'Position', [830 5 45 20], 'Callback', 'Stop_Callback');
    h_recalculate = uicontrol('Style', 'pushbutton', 'String', ' Recalculate ',...
    'Position', [750 5 75 20], 'Callback', 'Discard_Callback');
    uiwait
    
    if IMIN == -20;
                output = [i, headerdata(i,1)/86400-693960, str2num(discardstart), str2num(interval), str2num(mode), noise_gas, str2num(watercorrection), conc_unit_factor,...
                min(calcmatrix_nan_removed(:,1))/86400-693960, max(calcmatrix_nan_removed(:,1))/86400-693960, min(calcmatrix1(:,1)), max(calcmatrix1(:,1)),...
                N, mean(y), std(y), min(y), max(y), fitcoeff_lin(1), se_lin(1), relerr_lin(1), fitcoeff_lin(2), se_lin(2), relerr_lin(2), t_lin, prob_lin,...
                rsq_lin, rsq_lin_adj, SSR_lin, resStdev_lin, rmse_lin, Qx, SSR_norm_lin, chi2_p_lin, BIC_lin, AICc_lin, flux_lin, flux_lin_abserr, flux_lin_y_without, flux_lin_abserr_y_without...
                fitcoeff_pol2(1), se_pol2(1), relerr_pol2(1), fitcoeff_pol2(2), se_pol2(2), relerr_pol2(2), fitcoeff_pol2(3), se_pol2(3), relerr_pol2(3), t_pol2, prob_pol2,...
                rsq_pol2, rsq_pol2_adj, SSR_pol2, resStdev_pol2, rmse_pol2, SSR_norm_pol2, chi2_p_pol2, BIC_pol2, AICc_pol2, flux_pol2, flux_pol2_abserr, devfac_pol2,...
                fitcoeff_pol3(1), se_pol3(1), relerr_pol3(1), fitcoeff_pol3(2), se_pol3(2), relerr_pol3(2), fitcoeff_pol3(3), se_pol3(3), relerr_pol3(3), ...
                fitcoeff_pol3(4), se_pol3(4), relerr_pol3(4), t_pol3, prob_pol3, rsq_pol3, rsq_pol3_adj, SSR_pol3, resStdev_pol3, rmse_pol3, SSR_norm_pol3, chi2_p_pol3, BIC_pol3, AICc_pol3, flux_pol3, flux_pol3_abserr, devfac_pol3, ...
                order_before1,...
                fitcoeff_exp(1), se_exp(1), relerr_exp(1), fitcoeff_exp(2), se_exp(2), relerr_exp(2), fitcoeff_exp(3), se_exp(3), relerr_exp(3), t_exp, prob_exp,...
                rsq_exp, rsq_exp_adj, SSR_exp, resStdev_exp, rmse_exp, SSR_norm_exp, chi2_p_exp, BIC_exp, AICc_exp, ...
                offset_exp, abserr_offset_exp, relerr_offset_exp, slope_exp, abserr_slope_exp, relerr_slope_exp, flux_exp, flux_exp_abserr, devfac_exp,...
                fitcoeff_powser17(1), se_powser17(1), relerr_powser17(1), fitcoeff_powser17(2), se_powser17(2), relerr_powser17(2), fitcoeff_powser17(3), se_powser17(3), relerr_powser17(3), t_powser17, prob_powser17,...
                rsq_powser17, rsq_powser17_adj, SSR_powser17, resStdev_powser17, rmse_powser17, SSR_norm_powser17, chi2_p_powser17, BIC_powser17, AICc_powser17, flux_powser17, flux_powser17_abserr, devfac_powser17, error_powser17,...
                P_Var_kleiner_lin, P_Var_kleiner_pol2, P_Var_kleiner_pol3, P_Var_kleiner_exp, P_Var_kleiner_powser17, P_Var_kleiner_living, P_Var_kleiner_powser17alspol2, P_Var_kleiner_livingalspowser17, devfac_powser17zupol2, devfac_livingzupowser17,...
                d_lin, dL_2P, dU_2P, d_pol2, dL_3P, dU_3P, d_pol3, dL_4P, dU_4P, d_exp, dL_3P, dU_3P, d_powser17, dL_3P, dU_3P, d_living, dL_3P, dU_3P,...
                PKS_lin, PKS_pol2, PKS_pol3, PKS_exp, PKS_powser17, PKS_living,...
                P_dAgos_lin, P_dAgos_pol2, P_dAgos_pol3, P_dAgos_exp, P_dAgos_powser17, P_dAgos_living, o,...
                fitcoeff_powser17_comb(1), se_powser17_comb(1), relerr_powser17_comb(1), fitcoeff_powser17_comb(2), se_powser17_comb(2), relerr_powser17_comb(2),fitcoeff_powser17_comb(3), se_powser17_comb(3), relerr_powser17_comb(3), fitcoeff_combined(4), fitcoeff_combined(5), wendepunkt, wendepunktssteigung,...
                rsq_powser17_comb, rsq_powser17_comb_adj, SSR_powser17_comb, resStdev_powser17_comb, rmse_powser17_comb, SSR_norm_powser17_comb, chi2_p_powser17_comb, BIC_powser17_comb, AICc_powser17_comb,...
                fitcoeff_living(1), se_living(1), relerr_living(1), fitcoeff_living(2), se_living(2), relerr_living(2), fitcoeff_living(3), se_living(3), relerr_living(3), t_living, prob_living,...
                rsq_living, rsq_living_adj, SSR_living, resStdev_living, rmse_living, SSR_norm_living, chi2_p_living, BIC_living, AICc_living, flux_living, flux_living_abserr, devfac_living...
                mean_PAR_all, std_PAR_all, mean_PAR_10first, std_PAR_10first, mean_Tin_all, std_Tin_all, mean_Tin_10first, std_Tin_10first, mean_Tsoil_all, std_Tsoil_all, mean_Tsoil_10first, std_Tsoil_10first,...
                mean_VWC_all, std_VWC_all, mean_h2o_all, std_h2o_all, mean_h2o_10first, std_h2o_10first, e_sat_all, e_sat_10first, VPD_all, VPD_10first ,...
                headerdata(i,1)/86400-693960, headerdata(i,2)/86400-693960, headerdata(i,3:headercolumns)];
                        
                    metdata_output = [i, metdata(j_met,1)/86400-693960, metdata(j_met,2:metdatacolumns)];
            o=1; 
    dlmwrite(csvfilename, output, '-append', 'precision', 15) ;
    metdatacsvfilename=['met_', csvfilename];
    dlmwrite(metdatacsvfilename, metdata_output, '-append', 'precision', 15) ;
    % Saving of diagram figure: Name: 'year_month_day_hour_minute_second_gas_vs_time.jpg'
    set(gcf, 'PaperPositionMode', 'auto')% 'PaperSize', [1018, 673])
     saveas(gcf,[num2str(datetime1(1)), month, day, '_', hour1, minute1, second1, '_', num2str(headerdata(i,idcol)),'_',gas, '_conc_vs_time', '.png']);
          
       delete(gcf)
        break
    else
        api1 = iptgetapi(h_low)
    imline1_id = api1.getPosition()
    api2 = iptgetapi(h_high)
    imline2_id = api2.getPosition()
    if str2num(mode) == 1
    if imline1_id(1) <= imline2_id(1)
        if ha == 0
        manual_discard_start = calcmatrix_nan_removed(1,1) + round2n(imline1_id(1), 0) - (calcmatrix_nan_removed(1,1)-headerdata(i,1))
        manual_discard_end = calcmatrix_nan_removed(1,1) + round2n(imline2_id(1), 0) - (calcmatrix_nan_removed(1,1)-headerdata(i,1))
        else
        manual_discard_start = calcmatrix_nan_removed(1,1) + round2n(imline1_id(1), 0) - (calcmatrix_nan_removed(1,1)-rawdata(min(j_search),timecol))
        manual_discard_end = calcmatrix_nan_removed(1,1) + round2n(imline2_id(1), 0) - (calcmatrix_nan_removed(1,1)-rawdata(min(j_search),timecol))
        end
    else
        if ha == 0
        manual_discard_start = calcmatrix_nan_removed(1,1) + round2n(imline2_id(1), 0) - (calcmatrix_nan_removed(1,1)-headerdata(i,1))
        manual_discard_end = calcmatrix_nan_removed(1,1) + round2n(imline1_id(1), 0) - (calcmatrix_nan_removed(1,1)-headerdata(i,1))
        else
        manual_discard_start = calcmatrix_nan_removed(1,1) + round2n(imline2_id(1), 0) - (calcmatrix_nan_removed(1,1)-rawdata(min(j_search),timecol))
        manual_discard_end = calcmatrix_nan_removed(1,1) + round2n(imline1_id(1), 0) - (calcmatrix_nan_removed(1,1)-rawdata(min(j_search),timecol))
        end
    end
    elseif str2num(mode)== 0
    if imline1_id(1) <= imline2_id(1)
        manual_discard_start = calcmatrix_nan_removed(1,1) + round2n(imline1_id(1), 0)
        manual_discard_end = calcmatrix_nan_removed(1,1) + round2n(imline2_id(1), 0) 
    else
        manual_discard_start = calcmatrix_nan_removed(1,1) + round2n(imline2_id(1), 0) 
        manual_discard_end = calcmatrix_nan_removed(1,1) + round2n(imline1_id(1), 0) 
    end
    end
    
    i=i-1
    end
    
    
    elseif IMIN == -20;
      
              output = [i, headerdata(i,1)/86400-693960, str2num(discardstart), str2num(interval), str2num(mode), noise_gas, str2num(watercorrection), conc_unit_factor,...
                min(calcmatrix_nan_removed(:,1))/86400-693960, max(calcmatrix_nan_removed(:,1))/86400-693960, min(calcmatrix1(:,1)), max(calcmatrix1(:,1)),...
                N, mean(y), std(y), min(y), max(y), fitcoeff_lin(1), se_lin(1), relerr_lin(1), fitcoeff_lin(2), se_lin(2), relerr_lin(2), t_lin, prob_lin,...
                rsq_lin, rsq_lin_adj, SSR_lin, resStdev_lin, rmse_lin, Qx, SSR_norm_lin, chi2_p_lin, BIC_lin, AICc_lin, flux_lin, flux_lin_abserr, flux_lin_y_without, flux_lin_abserr_y_without...
                fitcoeff_pol2(1), se_pol2(1), relerr_pol2(1), fitcoeff_pol2(2), se_pol2(2), relerr_pol2(2), fitcoeff_pol2(3), se_pol2(3), relerr_pol2(3), t_pol2, prob_pol2,...
                rsq_pol2, rsq_pol2_adj, SSR_pol2, resStdev_pol2, rmse_pol2, SSR_norm_pol2, chi2_p_pol2, BIC_pol2, AICc_pol2, flux_pol2, flux_pol2_abserr, devfac_pol2,...
                fitcoeff_pol3(1), se_pol3(1), relerr_pol3(1), fitcoeff_pol3(2), se_pol3(2), relerr_pol3(2), fitcoeff_pol3(3), se_pol3(3), relerr_pol3(3), ...
                fitcoeff_pol3(4), se_pol3(4), relerr_pol3(4), t_pol3, prob_pol3, rsq_pol3, rsq_pol3_adj, SSR_pol3, resStdev_pol3, rmse_pol3, SSR_norm_pol3, chi2_p_pol3, BIC_pol3, AICc_pol3, flux_pol3, flux_pol3_abserr, devfac_pol3, ...
                order_before1,...
                fitcoeff_exp(1), se_exp(1), relerr_exp(1), fitcoeff_exp(2), se_exp(2), relerr_exp(2), fitcoeff_exp(3), se_exp(3), relerr_exp(3), t_exp, prob_exp,...
                rsq_exp, rsq_exp_adj, SSR_exp, resStdev_exp, rmse_exp, SSR_norm_exp, chi2_p_exp, BIC_exp, AICc_exp, ...
                offset_exp, abserr_offset_exp, relerr_offset_exp, slope_exp, abserr_slope_exp, relerr_slope_exp, flux_exp, flux_exp_abserr, devfac_exp,...
                fitcoeff_powser17(1), se_powser17(1), relerr_powser17(1), fitcoeff_powser17(2), se_powser17(2), relerr_powser17(2), fitcoeff_powser17(3), se_powser17(3), relerr_powser17(3), t_powser17, prob_powser17,...
                rsq_powser17, rsq_powser17_adj, SSR_powser17, resStdev_powser17, rmse_powser17, SSR_norm_powser17, chi2_p_powser17, BIC_powser17, AICc_powser17, flux_powser17, flux_powser17_abserr, devfac_powser17, error_powser17,...
                P_Var_kleiner_lin, P_Var_kleiner_pol2, P_Var_kleiner_pol3, P_Var_kleiner_exp, P_Var_kleiner_powser17, P_Var_kleiner_living, P_Var_kleiner_powser17alspol2, P_Var_kleiner_livingalspowser17, devfac_powser17zupol2, devfac_livingzupowser17,...
                d_lin, dL_2P, dU_2P, d_pol2, dL_3P, dU_3P, d_pol3, dL_4P, dU_4P, d_exp, dL_3P, dU_3P, d_powser17, dL_3P, dU_3P, d_living, dL_3P, dU_3P,...
                PKS_lin, PKS_pol2, PKS_pol3, PKS_exp, PKS_powser17, PKS_living,...
                P_dAgos_lin, P_dAgos_pol2, P_dAgos_pol3, P_dAgos_exp, P_dAgos_powser17, P_dAgos_living, o,...
                fitcoeff_powser17_comb(1), se_powser17_comb(1), relerr_powser17_comb(1), fitcoeff_powser17_comb(2), se_powser17_comb(2), relerr_powser17_comb(2),fitcoeff_powser17_comb(3), se_powser17_comb(3), relerr_powser17_comb(3), fitcoeff_combined(4), fitcoeff_combined(5), wendepunkt, wendepunktssteigung,...
                rsq_powser17_comb, rsq_powser17_comb_adj, SSR_powser17_comb, resStdev_powser17_comb, rmse_powser17_comb, SSR_norm_powser17_comb, chi2_p_powser17_comb, BIC_powser17_comb, AICc_powser17_comb,...
                fitcoeff_living(1), se_living(1), relerr_living(1), fitcoeff_living(2), se_living(2), relerr_living(2), fitcoeff_living(3), se_living(3), relerr_living(3), t_living, prob_living,...
                rsq_living, rsq_living_adj, SSR_living, resStdev_living, rmse_living, SSR_norm_living, chi2_p_living, BIC_living, AICc_living, flux_living, flux_living_abserr, devfac_living...
                mean_PAR_all, std_PAR_all, mean_PAR_10first, std_PAR_10first, mean_Tin_all, std_Tin_all, mean_Tin_10first, std_Tin_10first, mean_Tsoil_all, std_Tsoil_all, mean_Tsoil_10first, std_Tsoil_10first,...
                mean_VWC_all, std_VWC_all, mean_h2o_all, std_h2o_all, mean_h2o_10first, std_h2o_10first, e_sat_all, e_sat_10first, VPD_all, VPD_10first ,...
                headerdata(i,1)/86400-693960, headerdata(i,2)/86400-693960, headerdata(i,3:headercolumns)];
                        
                    metdata_output = [i, metdata(j_met,1)/86400-693960, metdata(j_met,2:metdatacolumns)];
            o=1; 
    dlmwrite(csvfilename, output, '-append', 'precision', 15) ;
    metdatacsvfilename=['met_', csvfilename];
    dlmwrite(metdatacsvfilename, metdata_output, '-append', 'precision', 15) ; 
    % Saving of diagram figure: Name: 'year_month_day_hour_minute_second_gas_vs_time.jpg'
    set(gcf, 'PaperPositionMode', 'auto')% 'PaperSize', [1018, 673])
    saveas(gcf,[num2str(datetime1(1)), month, day, '_', hour1, minute1, second1, '_', num2str(headerdata(i,idcol)),'_',gas, '_conc_vs_time', '.png']);
            
        delete(gcf)
        break
    end % end of filter IMIN
    end % end of filter manual control
        
    
    if control == 'f'
    %Saving in CSVfile
    if IMIN == 0 | IMIN == -2 | IMIN == -20
        if 1==1
                output = [i, headerdata(i,1)/86400-693960, str2num(discardstart), str2num(interval), str2num(mode), noise_gas, str2num(watercorrection), conc_unit_factor,...
                min(calcmatrix_nan_removed(:,1))/86400-693960, max(calcmatrix_nan_removed(:,1))/86400-693960, min(calcmatrix1(:,1)), max(calcmatrix1(:,1)),...
                N, mean(y), std(y), min(y), max(y), fitcoeff_lin(1), se_lin(1), relerr_lin(1), fitcoeff_lin(2), se_lin(2), relerr_lin(2), t_lin, prob_lin,...
                rsq_lin, rsq_lin_adj, SSR_lin, resStdev_lin, rmse_lin, Qx, SSR_norm_lin, chi2_p_lin, BIC_lin, AICc_lin, flux_lin, flux_lin_abserr, flux_lin_y_without, flux_lin_abserr_y_without...
                fitcoeff_pol2(1), se_pol2(1), relerr_pol2(1), fitcoeff_pol2(2), se_pol2(2), relerr_pol2(2), fitcoeff_pol2(3), se_pol2(3), relerr_pol2(3), t_pol2, prob_pol2,...
                rsq_pol2, rsq_pol2_adj, SSR_pol2, resStdev_pol2, rmse_pol2, SSR_norm_pol2, chi2_p_pol2, BIC_pol2, AICc_pol2, flux_pol2, flux_pol2_abserr, devfac_pol2,...
                fitcoeff_pol3(1), se_pol3(1), relerr_pol3(1), fitcoeff_pol3(2), se_pol3(2), relerr_pol3(2), fitcoeff_pol3(3), se_pol3(3), relerr_pol3(3), ...
                fitcoeff_pol3(4), se_pol3(4), relerr_pol3(4), t_pol3, prob_pol3, rsq_pol3, rsq_pol3_adj, SSR_pol3, resStdev_pol3, rmse_pol3, SSR_norm_pol3, chi2_p_pol3, BIC_pol3, AICc_pol3, flux_pol3, flux_pol3_abserr, devfac_pol3, ...
                order_before1,...
                fitcoeff_exp(1), se_exp(1), relerr_exp(1), fitcoeff_exp(2), se_exp(2), relerr_exp(2), fitcoeff_exp(3), se_exp(3), relerr_exp(3), t_exp, prob_exp,...
                rsq_exp, rsq_exp_adj, SSR_exp, resStdev_exp, rmse_exp, SSR_norm_exp, chi2_p_exp, BIC_exp, AICc_exp, ...
                offset_exp, abserr_offset_exp, relerr_offset_exp, slope_exp, abserr_slope_exp, relerr_slope_exp, flux_exp, flux_exp_abserr, devfac_exp,...
                fitcoeff_powser17(1), se_powser17(1), relerr_powser17(1), fitcoeff_powser17(2), se_powser17(2), relerr_powser17(2), fitcoeff_powser17(3), se_powser17(3), relerr_powser17(3), t_powser17, prob_powser17,...
                rsq_powser17, rsq_powser17_adj, SSR_powser17, resStdev_powser17, rmse_powser17, SSR_norm_powser17, chi2_p_powser17, BIC_powser17, AICc_powser17, flux_powser17, flux_powser17_abserr, devfac_powser17, error_powser17,...
                P_Var_kleiner_lin, P_Var_kleiner_pol2, P_Var_kleiner_pol3, P_Var_kleiner_exp, P_Var_kleiner_powser17, P_Var_kleiner_living, P_Var_kleiner_powser17alspol2, P_Var_kleiner_livingalspowser17, devfac_powser17zupol2, devfac_livingzupowser17,...
                d_lin, dL_2P, dU_2P, d_pol2, dL_3P, dU_3P, d_pol3, dL_4P, dU_4P, d_exp, dL_3P, dU_3P, d_powser17, dL_3P, dU_3P, d_living, dL_3P, dU_3P,...
                PKS_lin, PKS_pol2, PKS_pol3, PKS_exp, PKS_powser17, PKS_living,...
                P_dAgos_lin, P_dAgos_pol2, P_dAgos_pol3, P_dAgos_exp, P_dAgos_powser17, P_dAgos_living, o,...
                fitcoeff_powser17_comb(1), se_powser17_comb(1), relerr_powser17_comb(1), fitcoeff_powser17_comb(2), se_powser17_comb(2), relerr_powser17_comb(2),fitcoeff_powser17_comb(3), se_powser17_comb(3), relerr_powser17_comb(3), fitcoeff_combined(4), fitcoeff_combined(5), wendepunkt, wendepunktssteigung,...
                rsq_powser17_comb, rsq_powser17_comb_adj, SSR_powser17_comb, resStdev_powser17_comb, rmse_powser17_comb, SSR_norm_powser17_comb, chi2_p_powser17_comb, BIC_powser17_comb, AICc_powser17_comb,...
                fitcoeff_living(1), se_living(1), relerr_living(1), fitcoeff_living(2), se_living(2), relerr_living(2), fitcoeff_living(3), se_living(3), relerr_living(3), t_living, prob_living,...
                rsq_living, rsq_living_adj, SSR_living, resStdev_living, rmse_living, SSR_norm_living, chi2_p_living, BIC_living, AICc_living, flux_living, flux_living_abserr, devfac_living...
                mean_PAR_all, std_PAR_all, mean_PAR_10first, std_PAR_10first, mean_Tin_all, std_Tin_all, mean_Tin_10first, std_Tin_10first, mean_Tsoil_all, std_Tsoil_all, mean_Tsoil_10first, std_Tsoil_10first,...
                mean_VWC_all, std_VWC_all, mean_h2o_all, std_h2o_all, mean_h2o_10first, std_h2o_10first, e_sat_all, e_sat_10first, VPD_all, VPD_10first ,...
                headerdata(i,1)/86400-693960, headerdata(i,2)/86400-693960, headerdata(i,3:headercolumns)];
                        
                    metdata_output = [i, metdata(j_met,1)/86400-693960, metdata(j_met,2:metdatacolumns)];
            o=1;
    dlmwrite(csvfilename, output, '-append', 'precision', 15) ;
    metdatacsvfilename=['met_', csvfilename];
    dlmwrite(metdatacsvfilename, metdata_output, '-append', 'precision', 15) ;
    % Saving of diagram figure: Name: 'year_month_day_hour_minute_second_gas_vs_time.jpg'
    set(gcf, 'PaperPositionMode', 'auto')% 'PaperSize', [1018, 673])
    saveas(gcf,[num2str(datetime1(1)), month, day, '_', hour1, minute1, second1, '_', num2str(headerdata(i,idcol)), '_', lida, '_', gas, '_conc_vs_time', '.png']);
        end        
    end
    end    % end of if filter : not manual control
    %end % end of autocorrelation check
    if i == headerrows, break, end
    if IMIN == -20;
        delete(gcf)
        break
    end
    
    else
    output = [i, -9999]
    datetime1 = datevec(headerdata(i,1)/86400);   
    csvfilename = resultsfilename 
    dlmwrite(csvfilename, output, '-append', 'precision', 15)
   end   % end of if filter: data availability 2
    
   if i == headerrows, break, end
end;  % end of loop

end   % end of function

